
.soria .dijitSelectDisabled * {
    cursor: not-allowed !important;
}
.soria .dijitSelectReadOnly * {
    cursor: default !important;
}
.soria .dijitSelect .dijitButtonNode {
	padding: 0px;
}
.soria .dijitSelect .dijitButtonContents {
	padding-top: 1px;
    background:#fff url("../images/validationInputBg.png") repeat-x top left;
    #background:#fff url('../images/validationInputBg.gif') repeat-x top left;
}
.soria .dijitSelectHover .dijitButtonContents,
.soria .dijitSelectActive .dijitButtonContents,
.soria .dijitSelectOpened .dijitButtonContents,
.soria .dijitSelectDisabled .dijitButtonContents,
.soria .dijitSelectReadOnly .dijitButtonContents{
	background: transparent none;
}
.dj_ie .soria .dijitSelect .dijitButtonContents {
	padding-top: 0px;
}
.soria .dijitSelectDisabled .dijitButtonNode {
    border-color: #b9bbdd #b9bbdd #b9bbdd #b9bbdd;
    background:#c3d3e5 url("../images/buttonDisabled.png") top repeat-x;
}
.dj_ie .soria .dijitSelectDisabled  .dijitButtonNode * {
	filter: gray() alpha(opacity=50);
}
.soria .dijitSelectHover .dijitButtonNode {
    color:#000;
    background:#acc5e2 url("../images/buttonHover.png") repeat-x top left;
}
.soria .dijitSelectActive .dijitButtonNode,
.soria .dijitSelectOpened .dijitButtonNode {
    border-color:#657c9c;
    background: #91b4e5 url("../images/buttonActive.png") top left repeat-x;
}
.soria .dijitSelectMenu td {
	padding: 0em;
}
.soria .dijitSelectMenu .dijitMenuItemIcon {
	margin: 0.1em 0.2em;
	display: none;
}
.soria .dijitSelectMenu .dijitMenuItemLabel,
.soria .dijitSelectMenu .dijitMenuArrowCell {
	padding: 0.1em 0.2em;
}
