/*
	Copyright (c) 2004-2009, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/


if(!dojo._hasResource["dojox.form.DropDownSelect"]){
dojo._hasResource["dojox.form.DropDownSelect"]=true;
dojo.deprecated("dojox.form.DropDownSelect","Use dijit.form.Select instead","2.0");
dojo.provide("dojox.form.DropDownSelect");
dojo.require("dijit.form.Select");
dojo.setObject("dojox.form.DropDownSelect",dijit.form.Select);
}
