({"months-format-narrow":["1","2","3","4","5","6","7","8","9","10","11","12"],"quarters-standAlone-narrow":["1","2","3","4"],"*@localeAlias195":{"bundle":"islamic","target":"*"},"dateFormatItem-yQQQ":"y QQQ","dateFormatItem-yMEd":"EEE, y-M-d","dateFormatItem-MMMEd":"E MMM d","eraNarrow":["AH"],"eraNames@localeAlias213":{"bundle":"islamic","target":"eraAbbr"},"dateFormat@localeAlias215":{"bundle":"gregorian","target":"dateFormat"},"dateTimeFormats-appendItem-Day-Of-Week":"{0} {1}","dateFormat-long":"y MMMM d","months-format-wide":["Muharram","Safar","Rabiʻ I","Rabiʻ II","Jumada I","Jumada II","Rajab","Shaʻban","Ramadan","Shawwal","Dhuʻl-Qiʻdah","Dhuʻl-Hijjah"],"dateTimeFormat-medium":"{1} {0}","dateFormatItem-EEEd":"d EEE","dateFormat-full":"EEEE, y MMMM dd","timeFormat@localeAlias216":{"bundle":"gregorian","target":"timeFormat"},"dateFormatItem-Md":"M-d","days-standAlone-wide@localeAlias206":{"bundle":"gregorian","target":"days-format-wide"},"dateTimeFormats-appendItem-Second":"{0} ({2}: {1})","dateFormatItem-yM":"y-M","months-standAlone-wide":["Muharram","Safar","Rabiʻ I","Rabiʻ II","Jumada I","Jumada II","Rajab","Shaʻban","Ramadan","Shawwal","Dhuʻl-Qiʻdah","Dhuʻl-Hijjah"],"timeFormat-short":"HH:mm","quarters-format-wide":["Q1","Q2","Q3","Q4"],"timeFormat-long":"HH:mm:ss z","dateFormatItem-yMMM":"y MMM","dateFormatItem-yQ":"y Q","dateTimeFormats-appendItem-Era":"{0} {1}","months-format-abbr":["Muharram","Safar","Rabiʻ I","Rabiʻ II","Jumada I","Jumada II","Rajab","Shaʻban","Ramadan","Shawwal","Dhuʻl-Qiʻdah","Dhuʻl-Hijjah"],"timeFormat-full":"HH:mm:ss zzzz","dateTimeFormats-appendItem-Week":"{0} ({2}: {1})","am":"AM","months-standAlone-abbr":["Muharram","Safar","Rabiʻ I","Rabiʻ II","Jumada I","Jumada II","Rajab","Shaʻban","Ramadan","Shawwal","Dhuʻl-Qiʻdah","Dhuʻl-Hijjah"],"quarters-format-abbr":["Q1","Q2","Q3","Q4"],"quarters-standAlone-wide":["Q1","Q2","Q3","Q4"],"dateFormatItem-M":"L","days-standAlone-wide":["1","2","3","4","5","6","7"],"days-standAlone-abbr@localeAlias204":{"bundle":"gregorian","target":"days-format-abbr"},"dateFormatItem-MMMMd":"MMMM d","days-standAlone-abbr@localeAlias205":{"bundle":"gregorian","target":"days-format-wide"},"timeFormat-medium":"HH:mm:ss","dateFormatItem-Hm":"H:mm","quarters-standAlone-abbr":["Q1","Q2","Q3","Q4"],"eraAbbr":["AH"],"days-standAlone-abbr":["1","2","3","4","5","6","7"],"dateFormatItem-d":"d","dateFormatItem-ms":"mm:ss","quarters-standAlone-wide@localeAlias212":{"bundle":"gregorian","target":"quarters-format-wide"},"quarters-format-narrow":["1","2","3","4"],"months-standAlone-abbr@localeAlias198":{"bundle":"islamic","target":"months-format-abbr"},"months-standAlone-abbr@localeAlias199":{"bundle":"islamic","target":"months-format-wide"},"months-format-abbr@localeAlias196":{"bundle":"islamic","target":"months-format-wide"},"dateTimeFormat-long":"{1} {0}","days-format-abbr@localeAlias202":{"bundle":"gregorian","target":"days-format-wide"},"dateFormatItem-MMMd":"MMM d","dateFormatItem-MEd":"E, M-d","dateTimeFormat-full":"{1} {0}","dateFormatItem-yMMMM":"y MMMM","days-format-wide":["1","2","3","4","5","6","7"],"days-format-narrow@localeAlias203":{"bundle":"gregorian","target":"days-standAlone-narrow"},"dateTimeFormats-appendItem-Day":"{0} ({2}: {1})","dateFormatItem-y":"y","months-standAlone-narrow":["1","2","3","4","5","6","7","8","9","10","11","12"],"days@localeAlias201":{"bundle":"gregorian","target":"days"},"dateTime@localeAlias217":{"bundle":"gregorian","target":"dateTime"},"dateFormatItem-hm":"h:mm a","dateTimeFormats-appendItem-Year":"{0} {1}","dateTimeFormats-appendItem-Hour":"{0} ({2}: {1})","eraNarrow@localeAlias214":{"bundle":"islamic","target":"eraAbbr"},"days-format-abbr":["1","2","3","4","5","6","7"],"months-format-narrow@localeAlias197":{"bundle":"islamic","target":"months-standAlone-narrow"},"quarters-format-abbr@localeAlias208":{"bundle":"gregorian","target":"quarters-format-wide"},"quarters-format-narrow@localeAlias209":{"bundle":"gregorian","target":"quarters-standAlone-narrow"},"eraNames":["AH"],"days-format-narrow":["1","2","3","4","5","6","7"],"days-standAlone-narrow":["1","2","3","4","5","6","7"],"dateFormatItem-MMM":"LLL","dateTimeFormats-appendItem-Quarter":"{0} ({2}: {1})","quarters-standAlone-abbr@localeAlias210":{"bundle":"gregorian","target":"quarters-format-abbr"},"pm":"PM","quarters-standAlone-abbr@localeAlias211":{"bundle":"gregorian","target":"quarters-format-wide"},"dateTimeFormats-appendItem-Month":"{0} ({2}: {1})","dateFormatItem-MMMMEd":"E MMMM d","dateTimeFormats-appendItem-Minute":"{0} ({2}: {1})","dateFormat-short":"yyyy-MM-dd","months-standAlone-wide@localeAlias200":{"bundle":"islamic","target":"months-format-wide"},"dateFormatItem-yMMMEd":"EEE, y MMM d","dateTimeFormats-appendItem-Timezone":"{0} {1}","dateFormat-medium":"y MMM d","quarters@localeAlias207":{"bundle":"gregorian","target":"quarters"},"dateTimeFormat-short":"{1} {0}","dateFormatItem-Hms":"H:mm:ss","dateFormatItem-hms":"h:mm:ss a"})