
.tundra .dijitCalendarIncrementControl {
	
	width:15px;
	height:15px;
	background-image: url("images/spriteRoundedIconsSmall.png");
	background-repeat: no-repeat
}
.dj_ie6 .tundra .dijitCalendarIncrementControl {
	font-size:.1em;
	background-image: url("images/spriteRoundedIconsSmall.gif");
}
.tundra .dijitA11ySideArrow {
	display: none;
}
.tundra .dijitCalendarDecrease {
	background-position: top left;
}
.tundra .dijitCalendarIncrease {
	background-position: -30px top;
}
.tundra table.dijitCalendarContainer {
	font-size: 100%;
	border-spacing: 0;
	border-collapse: separate;
	border: 1px solid #ccc;
	margin: 0;
}
.tundra .dijitCalendarMonthContainer th {
	
	background:#d3d3d3 url("images/titleBar.png") repeat-x top;
	padding-top:.3em;
	padding-bottom:.2em;
	text-align:center;
}
.dj_ie6 .tundra .dijitCalendarMonthContainer th {
	padding-top:.2em;
	padding-bottom:.1em;
}
.tundra .dijitCalendarDayLabelTemplate {
	
	background:white url("images/calendarDayLabel.png") repeat-x bottom;
	font-weight:normal;
	padding-top:.15em;
	padding-bottom:0em;
	border-top: 1px solid #eeeeee;
	color:#293a4b;
	text-align:center;
}
.tundra .dijitCalendarBodyContainer {
	border-bottom: 1px solid #eeeeee;
}
.tundra .dijitCalendarMonthLabel {
	color:#293a4b;
	font-weight: bold;
}
.tundra .dijitCalendarDateTemplate {
	
	font-size: 0.9em;
	font-weight: bold;
	text-align: center;
	padding: 0.3em 0.3em 0.05em 0.3em;
	letter-spacing: 1px;
}
.dj_ie .tundra .dijitCalendarDateTemplate {
	padding: 0.1em .33em 0.02em .33em;
}
.tundra .dijitCalendarPreviousMonth,
.tundra .dijitCalendarNextMonth 		{
	
	color:#999999;
	background-color:#f8f8f8 !important;
}
.tundra .dijitCalendarPreviousMonthDisabled,
.tundra .dijitCalendarNextMonthDisabled	{
	
	background-color:#a4a5a6 !important;
}
.tundra .dijitCalendarCurrentMonth {
	
	background-color:white !important;
}
.tundra .dijitCalendarCurrentMonthDisabled {
	
	background-color:#bbbbbc !important;
}
.tundra .dijitCalendarDisabledDate {
	cursor:default !important;
	text-decoration:line-through !important;
}
.tundra .dijitCalendarCurrentDate {
	
	text-decoration:underline;
	font-weight:bold;
}
.tundra .dijitCalendarHoveredDate {
	background-color: #e2ebf2 !important;
}
.tundra .dijitCalendarSelectedDate {
	
	background-color:#bbc4d0 !important;
	color:black !important;
}
.tundra .dijitCalendarYearContainer {
	
	background:white url("images/calendarYearLabel.png") repeat-x bottom;
	border-top:1px solid #ccc;
}
.tundra .dijitCalendarYearLabel {
	
	margin:0;
	padding:0.4em 0 0.25em 0;
	text-align:center;
}
.tundra .dijitCalendarSelectedYear {
	
	color:black;
	padding:0.2em;
	padding-bottom:0.1em;
	background-color:#bbc4d0 !important;
}
.tundra .dijitCalendarNextYear,
.tundra .dijitCalendarPreviousYear {
	
	color:black !important;
	font-weight:normal;
}
