({"timeFormat-long":"H:mm:ss z","dateFormatItem-yM":"M/yyyy","field-dayperiod":"periodo del giorno","dateFormatItem-yQ":"Q-yyyy","field-minute":"minuto","eraNames":["a.C.","d.C"],"dateFormatItem-MMMEd":"EEE d MMM","field-weekday":"giorno della settimana","dateFormatItem-yQQQ":"QQQ y","dateFormatItem-MMdd":"dd/MM","days-standAlone-wide":["Domenica","Lunedì","Martedì","Mercoledì","Giovedì","Venerdì","Sabato"],"dateFormatItem-MMM":"LLL","months-standAlone-narrow":["G","F","M","A","M","G","L","A","S","O","N","D"],"field-era":"era","field-hour":"ora","dateFormatItem-hhmm":"hh.mm a","quarters-standAlone-abbr":["T1","T2","T3","T4"],"dateFormatItem-y":"y","timeFormat-full":"HH.mm.ss zzzz","months-standAlone-abbr":["gen","feb","mar","apr","mag","giu","lug","ago","set","ott","nov","dic"],"dateFormatItem-yMMM":"MMM y","days-standAlone-narrow":["D","L","M","M","G","V","S"],"eraAbbr":["aC","dC"],"dateFormatItem-yyyyMMMM":"MMMM y","dateFormat-long":"dd MMMM y","timeFormat-medium":"HH.mm.ss","field-zone":"zona","dateFormatItem-Hm":"HH:mm","dateFormatItem-yyMM":"MM/yy","dateFormat-medium":"dd/MMM/y","dateFormatItem-yyQQQQ":"QQQQ yy","quarters-standAlone-wide":["1o trimestre","2o trimestre","3o trimestre","4o trimestre"],"dateFormatItem-yMMMM":"MMMM y","dateFormatItem-ms":"mm:ss","field-year":"anno","quarters-standAlone-narrow":["1","2","3","4"],"dateFormatItem-HHmmss":"HH.mm.ss","months-standAlone-wide":["Gennaio","Febbraio","Marzo","Aprile","Maggio","Giugno","Luglio","Agosto","Settembre","Ottobre","Novembre","Dicembre"],"field-week":"settimana","dateFormatItem-MMMMEd":"EEE d MMMM","dateFormatItem-MMMd":"d MMM","dateFormatItem-HHmm":"HH.mm","dateFormatItem-yyQ":"Q yy","months-format-abbr":["gen","feb","mar","apr","mag","giu","lug","ago","set","ott","nov","dic"],"timeFormat-short":"HH.mm","field-month":"mese","quarters-format-abbr":["T1","T2","T3","T4"],"dateFormatItem-MMMMd":"d MMMM","days-format-abbr":["dom","lun","mar","mer","gio","ven","sab"],"dateFormatItem-MMMMdd":"dd MMMM","pm":"p.","dateFormatItem-M":"L","days-format-narrow":["D","L","M","M","G","V","S"],"field-second":"secondo","field-day":"giorno","dateFormatItem-MEd":"EEE d/M","months-format-narrow":["G","F","M","A","M","G","L","A","S","O","N","D"],"dateFormatItem-hhmmss":"hh.mm.ss a","am":"m.","days-standAlone-abbr":["dom","lun","mar","mer","gio","ven","sab"],"dateFormat-short":"dd/MM/yy","dateFormatItem-yMMMEd":"EEE d MMM y","dateFormat-full":"EEEE d MMMM y","dateFormatItem-Md":"d/M","dateFormatItem-yMEd":"EEE, d-M-yyyy","months-format-wide":["gennaio","febbraio","marzo","aprile","maggio","giugno","luglio","agosto","settembre","ottobre","novembre","dicembre"],"dateFormatItem-d":"d","quarters-format-wide":["1o trimestre","2o trimestre","3o trimestre","4o trimestre"],"days-format-wide":["domenica","lunedì","martedì","mercoledì","giovedì","venerdì","sabato"],"eraNarrow":["aC","dC"],"dateTimeFormats-appendItem-Day-Of-Week":"{0} {1}","dateTimeFormat-medium":"{1} {0}","dateFormatItem-EEEd":"d EEE","dateTimeFormats-appendItem-Second":"{0} ({2}: {1})","dateTimeFormats-appendItem-Era":"{0} {1}","dateTimeFormats-appendItem-Week":"{0} ({2}: {1})","quarters-format-narrow":["1","2","3","4"],"dateTimeFormat-long":"{1} {0}","dateTimeFormat-full":"{1} {0}","dateTimeFormats-appendItem-Day":"{0} ({2}: {1})","dateFormatItem-hm":"h:mm a","dateTimeFormats-appendItem-Year":"{0} {1}","dateTimeFormats-appendItem-Hour":"{0} ({2}: {1})","dateTimeFormats-appendItem-Quarter":"{0} ({2}: {1})","dateTimeFormats-appendItem-Month":"{0} ({2}: {1})","dateTimeFormats-appendItem-Minute":"{0} ({2}: {1})","dateTimeFormats-appendItem-Timezone":"{0} {1}","dateTimeFormat-short":"{1} {0}","dateFormatItem-Hms":"H:mm:ss","dateFormatItem-hms":"h:mm:ss a"})