
.soria .dijitToggleButton .dijitRadio,
.soria .dijitToggleButton .dijitRadioIcon {
	background-image: url('../images/spriteRadio.gif');
}
.soria .dijitRadio,
.soria .dijitRadioIcon	{		
	background-image: url('../images/spriteRadio.gif'); 
	background-repeat: no-repeat;
	width: 16px;
	height: 16px;
	margin: 0;
	padding: 0;
}
.soria .dijitRadio,
.soria .dijitToggleButton .dijitRadioIcon {
	
	background-position: -16px;
}
.soria .dijitRadioChecked,
.soria .dijitToggleButtonChecked .dijitRadioIcon {
	
	background-position: 0px;
}
.soria .dijitRadioDisabled {
	
	background-position: -48px;
}
.soria .dijitRadioCheckedDisabled {
	
	background-position: -32px;
}
.soria .dijitRadioHover {
	
	background-position: -80px;
}
.soria .dijitRadioCheckedHover {
	
	background-position: -64px;
}
