({"buttonSet":"设置","insertTableTitle":"插入表","insertTableRowAfterLabel":"在之后添加行","center":"居中","deleteTableColumnLabel":"删除列","right":"右","insertTableColumnBeforeLabel":"在之前添加列","tableWidth":"表宽度：","buttonInsert":"插入","default":"缺省值","align":"对齐：","insertTableRowBeforeLabel":"在之前添加行","cellSpacing":"单元格间距：","pixels":"像素","selectTableLabel":"选择表","rows":"行：","modifyTableTitle":"修改表","cellPadding":"单元格边距：","deleteTableRowLabel":"删除行","backgroundColor":"背景色：","insertTableColumnAfterLabel":"在之后添加列","left":"左","borderThickness":"边框厚度","columns":"列：","percent":"百分比","borderColor":"边框颜色："})