.dijitRtl .soria .dijitTab {
	margin-right:0;
	margin-left:2px;		
}
.dijitRtl .soria .dijitTabContainer .tabStripButton {
	margin-left: 0;
}
.dijitRtl .soria .dijitTabContainerTopStrip,
.dijitRtl .soria .dijitTabContainerBottomStrip,
.dijitRtl .soria .dijitTabContainerTop-tabs,
.dijitRtl .soria .dijitTabContainerBottom-tabs {
	padding-left: 0;
	padding-right: 3px;
}
.dijitRtl .soria .dijitTabInnerDiv {
	padding-left: 3px;
	padding-right: 4px;
}
.dijitRtl .soria .dijitTabPaneWrapper {
	#zoom: 1;
}
.dj_ie-rtl .soria .dijitTabContainerLeft-tabs {
	margin-left: 0px !important;
}
.dj_ie-rtl .soria .dijitTabContainerRight-tabs {
	margin-right: 0px !important;
}
.dijitRtl .soria .dijitTabContainerLeft-tabs .dijitTab,
.dijitRtl .soria .dijitTabContainerRight-tabs .dijitTab {
	margin-left:0px;
}
.dj_ie-rtl .soria .dijitTab .dijitTabInnerDiv{
	width : 1%;
}
