
.dojoxUpgradeBar {
	position:absolute;
	left:0;
	top:0;
	width:100%;
	height:32px;
	overflow:hidden;
	z-index:100;
	background:#f3f2af;
	box-shadow:0 2px 6px #444;
	-webkit-box-shadow:0 1px 6px #444;
	-moz-box-shadow:0 1px 6px #444;
	font-size:.8em;
}
.dj_ie .dojoxUpgradeBar {
	border-bottom:#665F48 2px solid;
}
.dojoxUpgradeBarMessage {
	position:absolute;
	padding-left:10px;
	top:50%;
	margin-top:-.75em;
	left:5px;
	width:100%;
}
.dojoxUpgradeBarMessage a{
	margin-left:10px;
}
.dojoxUpgradeBarReminderButton {
	position:absolute;
	top:25%;
	margin-right:50px;
	font-size:11px;
	text-decoration:underline;
	text-align:right;
	cursor:pointer;
	right:-20px;
}
.dj_ie6 .dojoxUpgradeBarReminderButton {
	margin-top:2px;
}
.dojoxUpgradeBarCloseIcon {
	background: url("../../../dijit/themes/tundra/images/tabClose.png") no-repeat right top;
	position: absolute;
	vertical-align: middle;
	right: 5px;
	top: 30%;
	height: 15px;
	width: 15px;
	cursor: pointer;
}
.dj_ie6 .dojoxUpgradeBarCloseIcon {
	background : url("../../../dijit/themes/tundra/images/tabClose.gif") no-repeat right top;
}
.dojoxUpgradeBarCloseIcon-hover {
	background: url("../../../dijit/themes/tundra/images/tabCloseHover.png") no-repeat right top;
}
.dj_ie6 .dojoxUpgradeBarCloseIcon-hover {
	background : url("../../../dijit/themes/tundra/images/tabCloseHover.gif") no-repeat right top;
}
