.dijitAdditionalEditorIconSmiley {
	background-image: url(../icons/smiley.gif);
	background-repeat: no-repeat;
	background-position: center center;
	width: 18px;
	height: 18px;
}
.dijitDisabled .dijitAdditionalEditorIconSmiley {
	background-image: url(../icons/insertEntityDisabled.gif); 
	background-repeat: no-repeat;
	background-position: center center;
	width: 18px;
	height: 18px;
}
.dojoxEntityPalette {
	border:1px solid #999;
	background:#fff;
	-moz-border-radius:3pt;
}
.dojoxEntityPaletteTable {
	position: relative;
	overflow:hidden;
	outline-color: black;
	outline-style: none;
	outline-width: 0;
	border: 0px solid black;
	border-collapse: separate;
	border-spacing: 2px;
	margin: 2px;
	table-layout: auto;
}
.dojoxEntityPaletteCell {
	border: 1px dotted gray;
	width: 20px;
	height: 20px;
	overflow: hidden;
	z-index: 10;
	text-align: center;
}
.dojoxEntityPaletteNullCell {
	border: none;
	width: 20px;
	height: 20px;
	overflow: hidden;
}
.dojoxEntityPaletteCellHighlight {
	width: 16px; 
	height: 14px; 
	overflow: hidden;
	cursor: default;
	border:2px solid #000;
	outline:1px solid #dedede;
}
.dijit_a11y .dojoxEntityPaletteCell {
	background-color:transparent !important;
}
.dijit_a11y .dojoxSmileyPaletteImg {
	background-color:transparent !important;
}
.dojoxSmileyPaletteImg {
	width: 16px; 
	height: 14px; 
	top: 1px;
	left: 1px;
	overflow: hidden;
	cursor: default;
	border:1px solid #999;
	
}
