.nihilo .dijitToolbar {
	border-bottom: 1px solid #ccc;
	background:#eaeaea url("images/titleBar.png") repeat-x top left;
}
.dj_ie6 .nihilo .dijitToolbar {
	height: 10px;
}
.nihilo .dijitToolbar .dijitButtonNode,
.nihilo .dijitToolbar .dijitComboButton .dijitButtonContents,
.nihilo .dijitToolbar .dijitComboButton .dijitDownArrowButton {
	background: none;
	margin: 0px;
	padding: 0px;
	border: none;
	font-size: 12px;
}
.nihilo .dijitToolbar .dijitButton,
.nihilo .dijitToolbar .dijitToggleButton,
.nihilo .dijitToolbar .dijitDropDownButton,
.nihilo .dijitToolbar .dijitComboButton .dijitButtonContents,
.nihilo .dijitToolbar .dijitComboButton .dijitDownArrowButton {
	background: none;
	padding: 1px;	
}
.nihilo .dijitToolbar .dijitButtonChecked,
.nihilo .dijitToolbar .dijitToggleButtonChecked {
	background-color:#ffeeb9;
	border:1px solid #f7c95c;
	padding: 0;
}
.nihilo .dijitToolbar .dijitButtonCheckedHover,
.nihilo .dijitToolbar .dijitToggleButtonCheckedHover
 {
	background-color:#ffe284;
	border:1px solid #f7c95c;
	padding: 0;
}
.nihilo .dijitToolbar .dijitButtonHover,
.nihilo .dijitToolbar .dijitToggleButtonHover,
.nihilo .dijitToolbar .dijitDropDownButtonHover,
.nihilo .dijitToolbar .dijitComboButtonHover .dijitButtonContents,
.nihilo .dijitToolbar .dijitComboButtonDownArrowHover .dijitDownArrowButton {
	
	border: 1px solid #f7c95c;
	padding: 0;
	background-color:#ffe284;
}
.nihilo .dijitToolbar label {
	padding: 3px 3px 0 6px;
}
.dj_ie .nihilo .dijitToolbar .dijitComboButton .dijitButtonContentsFocused,
.dj_ie .nihilo .dijitToolbar .dijitComboButton .dijitDownArrowButtonFocused {
	
	border: 1px #555 dotted !important;
	padding: 0px;
}
