
.dijitRtl .nihilo .dijitSliderProgressBarH,
.dijitRtl .nihilo .dijitSliderRemainingBarH,
.dijitRtl .nihilo .dijitSliderLeftBumper,
.dijitRtl .nihilo .dijitSliderRightBumper,
.dijitRtl .nihilo .dijitSliderTopBumper {
	background-position: top right;
}
.dijitRtl .nihilo .dijitSliderProgressBarV,
.dijitRtl .nihilo .dijitSliderRemainingBarV,
.dijitRtl .nihilo .dijitSliderBottomBumper {
	background-position: bottom right;
}
.dijitRtl .nihilo .dijitSliderLeftBumper {
	border-left-width: 0px;
	border-right-width: 1px;
}
.dijitRtl .nihilo .dijitSliderRightBumper {
	border-left-width: 1px;
	border-right-width: 0px;
}
.dijitRtl .nihilo .dijitSliderIncrementIconH {
	background:url('../images/spriteRoundedIconsSmall.png') no-repeat left top;
	#background:url('../images/spriteRoundedIconsSmall.gif') no-repeat left top;
}
.dijitRtl .nihilo .dijitSliderDecrementIconH {
	background:url('../images/spriteRoundedIconsSmall.png') no-repeat -30px top;
	#background:url('../images/spriteRoundedIconsSmall.gif') no-repeat -30px top;
}
