.dojoxLoaderPointer {
	position:absolute; 
	z-index:999; 
}
.dojoxLoader {
	float:right; 
	position:fixed; 
	height:25px;
	width:100px; 
	top:0;
	right:0; 
	padding:3px; 
	border:1px solid #ccc;
	background:#fff;  
	min-width:42px; 
}
.dojoxLoaderIcon {
	height:22px; width:22px; 
	vertical-align:middle; 
}
.dojoxLoaderMessage {
	font:8pt Arial,san-serif;
	color:#666; 
}
