.dojoxRating ul {
	padding:0;
	margin:0;
}
.dojoxRatingStar {
	display:inline-block;
	background-image:url(images/rating_empty.gif);
	background-position:left center;
	position:relative;
	height:15px;
	width:15px;
	float:left;
}
.dojoxRatingStarChecked {
	background-image:url(images/rating_full.gif);
}
.dojoxRatingStarHover {
	background-image:url(images/rating_full.gif);
	opacity:.5;
}
