({"buttonSet":"Задать","insertTableTitle":"Вставить таблицу","insertTableRowAfterLabel":"Добавить строку после","center":"по центру","deleteTableColumnLabel":"Удалить столбец","right":"справа","insertTableColumnBeforeLabel":"Добавить столбец до","tableWidth":"Ширина таблицы:","buttonInsert":"Вставить","default":"по умолчанию","align":"Выровнять:","insertTableRowBeforeLabel":"Добавить строку до","cellSpacing":"Отступ в ячейке:","pixels":"пикс.","selectTableLabel":"Выбрать таблицу","rows":"Строки:","modifyTableTitle":"Изменить таблицу","cellPadding":"Заполнение ячеек:","deleteTableRowLabel":"Удалить строку","backgroundColor":"Цвет фона:","insertTableColumnAfterLabel":"Добавить столбец после","left":"слева","borderThickness":"Ширина рамки","columns":"Столбцы:","percent":"проц.","borderColor":"Цвет рамки:"})