
.EditorTableDialog{
}
.EditorTableDialog .etdTable{
	width:350px;
	border:none;
	table-layout:fixed;
	border-collapse:collapse;
}
.EditorTableDialog .etdTable td{
	width:200px;
	border:#CCCCCC 0px solid;
	padding:5px;
}
.EditorTableDialog .etdTable td.left{
	width:200px;
}
.EditorTableDialog .etdTable td.right{
	width:150px;
}
.EditorTableDialog .dijitTextBox{
	width:50px;
	float:right;
	padding-left:3px;
}
.EditorTableDialog .dijitComboBox{
	width:85px;
	padding-left:5px;
}
.EditorTableDialog .etdTable .floatDijit{
	float:right;
}
.EditorTableDialog label{
	float:right;
	margin:0;
	margin-right:5px;
}
.EditorTableDialog .cellpad{
	background:url(images/cellpad.png) no-repeat 5px;
}
.EditorTableDialog .cellspace{
	background:url(images/cellspace.png) no-repeat 5px;
}
.dialogButtonContainer{
	text-align:right;
	margin-top:10px;
	cursor:pointer;
}
.colorSwatchBtn{
	display:block;
	border:#666666 2px solid;
	background-color:#CCCCCC;
	width:16px;
	height:16px;
	cursor:pointer;
	float:right;
}
.colorSwatchBtn:hover{
	border:#0099FF 2px solid;
}
.colorSwatchBtn div{
	background-color:#CCCCCC;
	width:16px;
	height:16px;
	cursor:pointer;
}
.editorIcon{
	background-image:url(images/tableIcons.png);
	background-repeat: no-repeat;
	width: 16px;
	height: 16px;
	text-align: center;
}
.editorIconUploadImage{
	background:url(images/uploadImageIcon.gif) no-repeat 0px 4px;
}
.editorIconInsertTable{				
	background-position:0px 0px;	}
.editorIconInsertTableRowBefore{ 	
	background-position:-19px 0px;	}
.dijitDisabled .editorIconInsertTableRowBefore{ 	
	background-position:-120px 0px;	}
	
.editorIconInsertTableRowAfter{ 	
	background-position:-35px 0px;	}
.dijitDisabled .editorIconInsertTableRowAfter{ 	
	background-position:-136px 0px;	}
.editorIconInsertTableColumnBefore{ 	
	background-position:-52px 0px;	}
.dijitDisabled .editorIconInsertTableColumnBefore{ 	
	background-position:-154px 0px;	}
	
.editorIconInsertTableColumnAfter{ 	
	background-position:-69px 0px;	}
.dijitDisabled .editorIconInsertTableColumnAfter{ 	
	background-position:-171px 0px;	}
	
.editorIconDeleteTableRow{ 	
	background-position:-86px 0px;	}
.dijitDisabled .editorIconDeleteTableRow{ 	
	background-position:-205px 0px;	}
	
.editorIconDeleteTableColumn{ 	
	background-position:-103px 0px;	}
.dijitDisabled .editorIconDeleteTableColumn{ 	
	background-position:-188px 0px;	}
	
.editorIconColorTableCell{ 	
	background-position:-222px 0px;	}
.dijitDisabled .editorIconColorTableCell{ 	
	background-position:-239px 0px;	}
.editorIconModifyTable{ 	
	background-position:-256px 0px;	}
.dijitDisabled .editorIconModifyTable{ 	
	background-position:-273px 0px;	}
.RichTextEditable .dijitTextBox, 
.RichTextEditable .dijitComboBox,
.RichTextEditable  .dijitSpinner {
	width: 5em;
}
.dojoxDropDownSelect {
	background:#FFFFFF url(images/dropBk.png) repeat-x scroll left top;
	border: 1px solid;
	border-top-color:#cccccc;
	border-right-color:#cccccc;
	border-left-color:#999999;
	border-bottom-color:#ffffff;
}
.dojoxDropDownSelect.dojoxDropDownSelectHover{
	background-image:url(images/dropBkOver.png);
}
.dojoxDropDownSelect button{
	line-height:16px;
	height:16px;
	width:100px;
	text-align:left;
	color:#8397b9;
}
.dijitButtonNode .dijitArrowButtonInner{
	
	background:url(../../../../dijit/themes/tundra/images/spriteArrows.png) no-repeat left top;
	width:7px;
}
.dojoxEditorUploadNorm{
	font-family:Arial;
	font-size:12px;
	
	
	vertical-align: middle;
	
	margin:0;
	line-height:normal;
	text-align:center;
	white-space: nowrap;
	
	cursor: pointer;
	background: #ccc url("images/uploadImageIcon.gif") no-repeat 2px 2px;
}
.dojoxEditorUploadHover{
	background: #ccc url("images/uploadImageIcon.gif") no-repeat 2px 0px;
}
.dojoxEditorUploadActive{
	background: #ccc url("images/uploadImageIcon.gif") no-repeat 2px 4px;
}
.dojoxEditorUploadDisabled{
	background: #ccc url("images/uploadImageIcon.gif") no-repeat 2px 2px;
}
