<div class="peopleEditor">
	<table style="width: 100%">
		<tbody dojoAttachPoint="peopleEditorEditors"></tbody>
	</table>
	<span class="peopleEditorButton" dojoAttachPoint="peopleEditorButton" dojoAttachEvent="onclick:_add"></span>
</div>