({"set":"设置","text":"说明：","insertImageTitle":"图像属性","url":"URL：","createLinkTitle":"链接属性","newWindow":"New Window","topWindow":"Topmost Window","target":"Target:","parentWindow":"Parent Window","currentWindow":"Current Window"})