
.tundra .dijitTreeNode {
    background-image : url('images/i.gif');
    background-repeat : repeat-y;
    zoom: 1;	
}
.tundra .dijitTreeIsLast {
    background: url('images/i_half.gif') no-repeat;
}
.tundra .dijitTreeIsRoot {
    margin-left: 0;
    background-image: none;
}
.tundra .dijitTreeExpando {
    width: 18px;
    height: 18px;
}
.tundra .dijitTreeRow {
	
	padding-bottom: 2px;
}
.tundra .dijitTreeContent {
    min-height: 18px;
    min-width: 18px;
 }
.tundra .dijitTreeExpand {
    width: 18px;
    height: 18px;
    background-repeat : no-repeat;
}
.tundra .dijitTreeNodeEmphasized {
    background-color: Highlight;
    color: HighlightText;
}
.tundra .dijitTreeLabelFocused {
	outline: 1px invert dotted;
}
.tundra .dijitTreeNodeSelected .dijitTreeLabel {
	background:#e2ebfe;
}
.tundra .dijitTreeNodeHover {
	
	
	background-image: url(images/treeHover.png);
	background-repeat: repeat;
	background-color: none !important;
}
.tundra .dijitTreeExpandoOpened {
	background-image: url('images/treeExpand_minus.gif');
}
.tundra .dijitTreeExpandoClosed {
	background-image: url('images/treeExpand_plus.gif');
}
.tundra .dijitTreeExpandoLeaf {
	background-image: url('images/treeExpand_leaf.gif');
}
.tundra .dijitTreeExpandoLoading {
	background-image: url('images/treeExpand_loading.gif');
}
.tundra .dijitTreeIcon {
	width: 16px;
	height: 16px;
}
.tundra .dijitFolderOpened {
	background: url('images/folderOpened.gif') no-repeat;
}
.tundra .dijitFolderClosed {
	background: url('images/folderClosed.gif') no-repeat;
}
.tundra .dijitLeaf {
	background: url('images/leaf.gif') no-repeat;
}
.tundra .dijitTreeNode .dojoDndItemBefore,
.tundra .dijitTreeNode .dojoDndItemAfter {
	border-bottom: none;
	border-top: none;
}
.tundra .dijitTreeNode .dojoDndItemBefore .dijitTreeContent {
	
	border-top: 2px solid #369;
}
.tundra .dijitTreeNode .dojoDndItemAfter .dijitTreeContent {
	
	border-bottom: 2px solid #369;
}
