.soria .dijitToolbar {
	border-bottom: 1px solid #ccc;
	background:#eaeaea url("images/titleBar.png") repeat-x top left;
}
.dj_ie6 .soria .dijitToolbar {
	height: 10px;
}
.soria .dijitToolbar .dijitButtonNode,
.soria .dijitToolbar .dijitComboButton .dijitButtonContents,
.soria .dijitToolbar .dijitComboButton .dijitDownArrowButton {
	background: none;
	margin: 0px;
	padding: 0px;
	border: none;
	font-size: 12px;
}
.soria .dijitToolbar .dijitButton,
.soria .dijitToolbar .dijitToggleButton,
.soria .dijitToolbar .dijitDropDownButton,
.soria .dijitToolbar .dijitComboButton .dijitButtonContents,
.soria .dijitToolbar .dijitComboButton .dijitDownArrowButton {
	background: none;
	padding: 1px;	
}
.soria .dijitToolbar .dijitButtonChecked,
.soria .dijitToolbar .dijitToggleButtonChecked {
	background-color:#d8e5f8;
	border:1px solid #316ac5;
	padding: 0px;
}
.soria .dijitToolbar .dijitButtonCheckedHover,
.soria .dijitToolbar .dijitToggleButtonCheckedHover
 {
	background-color:#9abbea;
	border:1px solid #316ac5;
	padding: 0px;
}
.soria .dijitToolbar .dijitButtonHover,
.soria .dijitToolbar .dijitToggleButtonHover,
.soria .dijitToolbar .dijitDropDownButtonHover,
.soria .dijitToolbar .dijitComboButtonHover .dijitButtonContents,
.soria .dijitToolbar .dijitComboButtonDownArrowHover .dijitDownArrowButton {
	
	border: 1px solid #316ac5;
	padding: 0px;
	background-color:#9abbea;
}
.soria .dijitToolbar label {
	padding: 3px 3px 0 6px;
}
.dj_ie .soria .dijitToolbar .dijitComboButton .dijitButtonContentsFocused,
.dj_ie .soria .dijitToolbar .dijitComboButton .dijitDownArrowButtonFocused {
	
	border: 1px #777 dotted !important;
	padding: 0px;
}
