({"buttonSet":"Beállítás","insertTableTitle":"Táblázat beszúrása","insertTableRowAfterLabel":"Sor hozzáadása utána","center":"középre","deleteTableColumnLabel":"Oszlop törlése","right":"jobbra","insertTableColumnBeforeLabel":"Oszlop hozzáadása elé","tableWidth":"Táblázat szélessége:","buttonInsert":"Beszúrás","default":"alapértelmezés","align":"Igazítás:","insertTableRowBeforeLabel":"Sor hozzáadása elé","cellSpacing":"Cellatávolság:","pixels":"pixel","selectTableLabel":"Táblázat kiválasztása","rows":"Sorok:","modifyTableTitle":"Táblázat módosítása","cellPadding":"Cellakitöltés:","deleteTableRowLabel":"Sor törlése","backgroundColor":"Háttérszín:","insertTableColumnAfterLabel":"Oszlop hozzáadása utána","left":"balra","borderThickness":"Szegélyvastagság","columns":"Oszlopok:","percent":"százalék","borderColor":"Szegélyszín:"})