.dijitAdditionalEditorIconFindReplace {
        background-image: url(../icons/findReplace.gif);
        background-repeat: no-repeat;
        background-position: center center;
        width: 18px;
        height: 18px;
}
.dijitDisabled .dijitAdditionalEditorIconFindReplace {
        background-image: url(../icons/findReplaceDisabled.gif);
        background-repeat: no-repeat;
        background-position: center center;
        width: 18px;
        height: 18px;
}
.dijitAdditionalEditorIconFindRun {
        background-image: url(../icons/findIcon.gif);
        background-repeat: no-repeat;
        background-position: center center;
        width: 18px;
        height: 18px;
        padding-left: 5px;
        padding-right: 5px;
}
.dijitAdditionalEditorIconReplaceRun {
        background-image: url(../icons/replaceIcon.gif);
        background-repeat: no-repeat;
        background-position: center center;
        width: 18px;
        height: 18px;
        padding-left: 5px;
        padding-right: 5px;
}
.dijitDisabled .dijitAdditionalEditorIconFindRun {
        background-image: url(../icons/findIconDisabled.gif);
        background-repeat: no-repeat;
        background-position: center center;
        width: 18px;
        height: 18px;
        padding-left: 5px;
        padding-right: 5px;
}
.dijitDisabled .dijitAdditionalEditorIconReplaceRun {
        background-image: url(../icons/replaceIconDisabled.gif);
        background-repeat: no-repeat;
        background-position: center center;
        width: 18px;
        height: 18px;
        padding-left: 5px;
        padding-right: 5px;
}
.findReplaceCheckBox {
        padding-left: 10px;
        padding-right: 10px;
        text-align: center;
}
.findReplaceTextBox {
        padding-top: 3px;
        padding-bottom: 3px;
}
