
.containerNode {
        visibility : visible;
}
.graphic-tab-lgray {
		margin-bottom: 10px;
}
.newgraphic-tab-lgray {
        border-bottom: #d9d9d9 solid 7px;
}
td.lp { 
        padding: 0px 13px 0px 10px;
        font-weight: bold;
        background: #d9d9d9;
        border-bottom: #d9d9d9 solid 7px;
}
td.lp2 { 
        background: #FFFFFF;
        border-bottom: #d9d9d9 solid 7px;
}
span.lp {
        padding: 0px 13px 0px 10px;
        font-weight: bold;
        background: #d9d9d9;
        border-bottom: #d9d9d9 solid 7px;
		width: auto;
}
