.dojoxGrid {
	position: relative;
	background-color: #EBEADB;
	font-family: Geneva, Arial, Helvetica, sans-serif;
	-moz-outline-style: none;
	outline: none;
	overflow: hidden;
	height: 0;
}
.dojoxGrid table {
	padding: 0;
}
.dojoxGrid td {
	-moz-outline: none;
}
.dojoxGridMasterHeader {
	position: relative;
}
.dojoxGridMasterView  {
	position: relative;
}
.dojoxGridMasterMessages {
	position: relative;
	padding: 1em;
	text-align: center;
	background-color: white;
}
.dojoxGridView {
	position: absolute;
	overflow: hidden;
}
.dojoxGridHeader {
	position: absolute;
	overflow: hidden;
	cursor: default;
}
.dojoxGridHeader {
	background-color: #E8E1CF;
}
.dojoxGridHeader table {
	text-align: center;
}
.dojoxGridHeader .dojoxGridCell { 
	border: 1px solid;
	border-color: #F6F4EB #ACA899 #ACA899 #F6F4EB;
	background: url(images/grid_dx_gradient.gif) #E8E1CF top repeat-x;
	padding-bottom: 2px;
}
.dojoxGridHeader .dojoxGridCellOver {
	background-image: none;
	background-color: white;
	border-bottom-color: #FEBE47;
	margin-bottom: 0;
	padding-bottom: 0;
	border-bottom-width: 3px;
}
.dojoxGridHeader .dojoxGridCellFocus {
	border: 1px dashed blue;
}
.dojoxGridHeader.dojoxGridCellFocus.dojoxGridCellOver {
	background-image: none;
	background-color: white;
	border-bottom-color: #FEBE47;
	margin-bottom: 0;
	padding-bottom: 0;
	border-bottom-width: 3px;
}
.dojoxGridArrowButtonNode {
	display: none;
	padding-left: 16px;
}
.dojoxGridArrowButtonChar {
	display:inline;
}
 
.dojoxGridArrowButtonNode:hover {
        cursor: default;
}
.dojoxGridArrowButtonChar:hover {
        cursor: default;
}
.dojoxGridSortUp:hover {
        cursor: default;
}
.dojoxGridSortDown:hover {
        cursor: default;
}
.dijit_a11y .dojoxGridArrowButtonChar {
	display:inline !important;
}
.dojoxGridScrollbox {
	position: relative;
	overflow: auto;
	background-color: white;
	width: 100%;
}
.dojoxGridContent {
	position: relative;
	overflow: hidden;
	 -moz-outline-style: none;
	outline: none;
}
.dojoxGridRowbar { 
	border: 1px solid;
	border-color: #F6F4EB #ACA899 #ACA899 #F6F4EB;
	border-top: none;
	background: url(images/grid_dx_gradient.gif) #E8E1CF top repeat-x;
}
.dojoxGridRowbarInner {
	border-top: 1px solid #F6F4EB;
}
.dojoxGridRowbarOver {
	background-image: none;
	background-color: white;
	border-top-color: #FEBE47;
	border-bottom-color: #FEBE47;
}
.dojoxGridRowbarSelected {
	background-color: #D9E8F9;
}
.dojoxGridRow {
	position: relative;
	width: 9000em;
}
.dojoxGridRow {
	
	border: 1px solid #E8E4D8;
	border-color: #F8F7F1;
	
	border-left: none;
	border-right: none;
	background-color: white;
	border-top: none;
}
.dojoxGridRowOver {
	border-top-color: #FEBE47;
	border-bottom-color: #FEBE47;
	
	
	
}
.dojoxGridRowOdd {
	background-color: #FFFDF3;
	
}
.dojoxGridRowSelected {
	background-color: #D9E8F9;
}
.dojoxGridRowTable {
	table-layout: fixed;
	width: 0;
	empty-cells: show;
}
.dj_ie .dojoxGridRowTable {
	border-collapse: collapse;
}
.dojoxGridInvisible {
	visibility: hidden;
}		
.Xdojo-ie .dojoxGridInvisible {
	display: none;
}		
.dojoxGridInvisible td, .dojoxGridHeader .dojoxGridInvisible td {
	border-top-width: 0;
	border-bottom-width: 0;
	padding-top: 0;
	padding-bottom: 0;
	height: 0;
	overflow: hidden;
}
.dojoxGridCell {
	border: 1px solid;
	border-color: #EBEADB;
	border-right-color: #D5CDB5;
	padding: 3px 3px 3px 3px;
	text-align: left;
	overflow: hidden;
}
.dojoxGridCellFocus {
	border: 1px dashed blue;
}
.dojoxGridCellOver {
	border: 1px dotted #FEBE47;
}
.dojoxGridCellFocus.dojoxGridCellOver {
	border: 1px dashed green;
}
.dojoxGridRowEditing td {
	background-color: #F4FFF4;
}
.dojoxGridRow-inserting td {
	background-color: #F4FFF4;
}
.dojoxGridRow-inflight td {
	background-color: #F2F7B7;
}
.dojoxGridRow-error td {
	background-color: #F8B8B6;
}
.dojoxGridInput, .dojoxGridSelect, .dojoxGridTextarea {
	margin: 0;
	padding: 0;
	border-style: none;
	width: 100%;
	font-size: 100%;
	font-family: inherit;
}
.dojoxGridHiddenFocus {
	position: absolute;
	top: -1000px;
	height: 0;
	width: 0;
}
.dijit_a11y .dojoxGridRowbarSelected { 
	border-top: 1px solid white;
	border-bottom: 1px dashed black;
	border-top: 0;
	background: none;
}
.dijit_a11y .dojoxGridRowbarSelected .dojoxGridRowbarInner {
	border: 0;
	border-top: 1px solid white;
}
.dijit_a11y .dojoxGridRowSelected {
	border: 1px solid black !important;
}
.dojoxGridDndAvatar {
	font-size: 100%;
}
.dojoxGrid .dojoDndItemBefore {
	border-left-color: red;
}
.dojoxGrid .dojoDndItemAfter {
	border-right-color: red;
}
.dijit_a11y .dojoDndItemBefore {
	border-left: double;
}
.dijit_a11y .dojoDndItemAfter {
	border-right: double;
}
.dojoxGridDndAvatarItem	td {
	border: 1px solid;
	border-color: #F6F4EB #ACA899 #ACA899 #F6F4EB;
	background: url(images/grid_dx_gradient.gif) #E8E1CF top repeat-x;
	padding: 0pt;
	margin: 0pt;
}
.dojoxGridDndAvatarItem	td.dojoxGridDndAvatarItemImage {
	border: 0;
	border-color: #F6F4EB #ACA899 #ACA899 #F6F4EB;
	background-color: transparent;
	padding: 3px;
	padding-bottom: 2px;
	margin: 0;
}
.dojoDndMove .dojoxGridDndAvatarItem .dojoxGridDndAvatarItemImage {
	background-image: url(../../../dojo/resources/images/dndNoMove.png);
	background-repeat: no-repeat;
	background-position: center center;
}
.dojoDndCopy .dojoxGridDndAvatarItem .dojoxGridDndAvatarItemImage {
	background-image: url(../../../dojo/resources/images/dndNoCopy.png);
	background-repeat: no-repeat;
	background-position: center center;
}
.dojoDndMove .dojoDndAvatarCanDrop .dojoxGridDndAvatarItem .dojoxGridDndAvatarItemImage {
	background-image: url(../../../dojo/resources/images/dndMove.png);
	background-repeat: no-repeat;
	background-position: center center;
}
.dojoDndCopy .dojoDndAvatarCanDrop .dojoxGridDndAvatarItem .dojoxGridDndAvatarItemImage {
	background-image: url(../../../dojo/resources/images/dndCopy.png);
	background-repeat: no-repeat;
	background-position: center center;
}
.dojoxGridColPlaceBottom {
	background: transparent url(images/grid_sort_up.gif) no-repeat scroll left top;
}
.dojoxGridColPlaceTop {
	background: transparent url(images/grid_sort_down.gif) no-repeat scroll left top;
}
.dojoxGridColPlaceTop, .dojoxGridColPlaceBottom {
	font-size:1px;
	height:6px;
	z-index:10000;
	top:0;
	overflow:hidden;
	position:absolute;
	line-height:1px;
	width:8px;
}
.dojoxGridResizeColLine {
	width: 1px;
	background-color: #777;
	position: absolute;
	cursor: col-resize;
	z-index:10000;
}
.dojoxGridColNoResize, 
.dojoxGridColNoResize .dojoDndItemOver {
	cursor: not-allowed !important;
}
.dojoxGridColResize, 
.dojoxGridColResize .dojoDndItemOver,
.dojoxGridColumnResizing,
.dojoxGridColumnResizing .dojoDndItemOver,
.dojoxGridColumnResizing .dojoxGridHeader {
	cursor: col-resize !important;
}
.dojoxGridColPlaceBottom {
	background: transparent url(images/grid_sort_up.gif) no-repeat scroll left top;
}
.dojoxGridColPlaceTop {
	background: transparent url(images/grid_sort_down.gif) no-repeat scroll left top;
}
.dojoxGridColPlaceTop, .dojoxGridColPlaceBottom {
	font-size:1px;
	height:6px;
	z-index:10000;
	top:0;
	overflow:hidden;
	position:absolute;
	line-height:1px;
	width:8px;
}
.dojoxGridResizeColLine {
	width: 1px;
	background-color: #777;
	position: absolute;
}
.dojoxGridExpandoCell {
	vertical-align: top;
}
.dojoxGridSummarySpan {
	visibility: hidden;
}
.dojoxGridSummaryRow .dojoxGridSummarySpan,
.dojoxGridRowCollapsed .dojoxGridSummarySpan {
	visibility: visible;
}
.dojoxGridNoChildren .dojoxGridExpando {
	visibility: hidden !important;
	width: 0px !important;
}
