({"buttonSet":"Ustaw","insertTableTitle":"Wstaw tabelę","insertTableRowAfterLabel":"Dodaj wiersz po","center":"wyśrodkuj","deleteTableColumnLabel":"Usuń kolumnę","right":"do prawej","insertTableColumnBeforeLabel":"Dodaj kolumnę przed","tableWidth":"Szerokość tabeli:","buttonInsert":"Wstaw","default":"wartość domyślna","align":"Wyrównaj:","insertTableRowBeforeLabel":"Dodaj wiersz przed","cellSpacing":"Odstępy między komórkami:","pixels":"piksle","selectTableLabel":"Wybieranie tabeli","rows":"Wiersze:","modifyTableTitle":"Modyfikuj tabelę","cellPadding":"Dopełnianie komórek:","deleteTableRowLabel":"Usuń wiersz","backgroundColor":"Kolor tła:","insertTableColumnAfterLabel":"Dodaj kolumnę po","left":"do lewej","borderThickness":"Grubość krawędzi","columns":"Kolumny:","percent":"procent","borderColor":"Kolor krawędzi:"})