
.dijitToasterContent {
	padding:1em;
	padding-top:0.25em;
	background:#73c74a;
}
.dijitToasterMessage{ 
	color:#fff;
}
.dijitToasterWarning{ }
.dijitToasterError,
.dijitToasterFatal{
	font-weight:bold;
	color:#fff;
}
.dijitToasterWarning .dijitToasterContent{
	padding:1em;
	padding-top:0.25em;
	background:#d4d943;
} 
.dijitToasterError .dijitToasterContent{
	padding:1em;
	padding-top:0.25em;
	background:#c46600;
}
 
.dijitToasterClip {
	position: absolute;
	z-index: 5000;
	overflow: hidden;
}
.dijitToasterContainer {
	display: block;
	position: absolute;
	width: 17.5em;
	margin: 0px;
	font:0.75em Tahoma, Helvetica, Verdana, Arial;
}
 
