
code {background-color: #eed}
code .comment {color: #228b22}
code .comment.preproc {color: #1e889b}
code .comment.special {color: #8b008b; font-weight: bold}
code .keyword {color: #8b008b; font-weight: bold}
code .keyword.type {color: #a7a7a7}
code .operator.word {color: #8b008b}
code .name.builtin {color: #658b00}
code .name.function {color: #008b45}
code .name.class {color: #008b45; font-weight: bold}
code .name.namespace {color: #008b45; text-decoration: underline}
code .name.exception {color: #008b45; font-weight: bold}
code .name.variable {color: #00688b}
code .name.constant {color: #00688b}
code .name.attribute {color: #658b00}
code .name.tag {color: #8b008b; font-weight: bold}
code .name.decorator {color: #707a7c}
code .string {color: #cd5555}
code .string.regex {color: #1c7e71}
code .string.other {color: #cb6c20}
code .string.heredoc {color: #1c7e71; font-style: italic}
code .number {color: #b452cd}
