/*
	Copyright (c) 2004-2009, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/


if(!dojo._hasResource["dojox.charting.themes.Desert"]){
dojo._hasResource["dojox.charting.themes.Desert"]=true;
dojo.provide("dojox.charting.themes.Desert");
dojo.require("dojox.charting.Theme");
(function(){
var _1=dojox.charting;
_1.themes.Desert=new _1.Theme({colors:["#ffebd5","#806544","#fdc888","#80766b","#cda26e"]});
})();
}
