.dojoxRangeSlider .dijitSliderLeftBumperH, .dojoxRangeSlider .dijitSliderBottomBumperV  {
    background:#FFFFFF !important;
}
.dojoxRangeSliderBarContainer {
    position:relative;
}
.dojoxRangeSlider .dijitSliderProgressBarV {
    position:relative !important;
}
.dojoxRangeSlider .dijitSliderProgressBar {
    overflow:hidden;
    cursor:pointer;
    
}
.dojoxRangeSlider .dijitSliderProgressBarV {
    position:absolute !important;
    border-width: 0px;
}
