.dojoxRollingList {
	border: 1px solid #000;
	height: 20em;
	background-color: #FFF;
	position: relative;
}
.dijitPopup .dojoxRollingList {
	position: static;
}
.dojoxRollingListContainer {
	overflow: scroll;
	overflow-y: hidden;
	overflow-x: scroll;
	white-space: nowrap;
}
.dojoxRollingListButtons {
	position: absolute;
	right: 5px;
	padding: 5px 0px;
}
.dojoxRollingListButtonsHidden .dojoxRollingListButtons {
	display: none;
}
.dojoxRollingListPane {
	overflow: scroll;
	overflow-x: hidden;
	overflow-y: scroll;
	display:-moz-inline-box;		
	display:inline-block;			
	#zoom: 1; 
	#display:inline; 
	border:0;
	padding:0;
	vertical-align:middle;
	#vertical-align: auto;	
}
.dojoxRollingListPane .dijitMenuItem td {
	width: 1px;
}
.dojoxRollingListPane .dijitMenuItem td.dijitMenuItemLabel {
	width: auto;
}
.dojoxRollingListPane .dijitMenuItemLabel,
.dojoxRollingListPane .dijitMenuItemIcon {
	position: static !important;
}
.dj_webkit .dojoxRollingListPane,
.dj_ie .dojoxRollingListPane {
	padding-right: 15px; 
}
.dojoxRollingListPane .dijitMenu {
	border: none !important;
}
.dojoxRollingListItem {
	cursor: default;
}
.tundra .dojoxRollingList {
	border-color: #b3b3b3;
}
.tundra .dijitPopup .dojoxRollingList {
	border-color: #406b9b;
}
.tundra .dojoxRollingListPane {
	background-color: #f7f7f7;
}
.tundra .dojoxRollingListPane .dojoxRollingListItemHover,
.tundra .dojoxRollingListPane .dojoxRollingListItemFocus {
	background-color: #e3e3e3;
}
.tundra .dojoxRollingListPane .dojoxRollingListItemSelected {
	color: #fff;
	background-color: #999;
	font-weight: bold;
}
.tundra .dojoxRollingListPaneCurrentSelected .dojoxRollingListItemSelected {
	background-color: #3559ac;
}
.tundra .dojoxRollingListPane .dojoxRollingListItemHoverSelected,
.tundra .dojoxRollingListPane .dojoxRollingListItemFocusSelected {
	background-color: #9aacd6;
}
.tundra .dojoxRollingListItem {
	font-family: inherit;
}
.soria .dojoxRollingList {
	border-color: #8ba0bd;
}
.soria .dijitPopup .dojoxRollingList {
	border-color: #406b9b;
}
.soria .dojoxRollingListPane {
	background-color: #fff;
}
.soria .dojoxRollingListPane .dojoxRollingListItemHover, 
.soria .dojoxRollingListPane .dojoxRollingListItemFocus {
	background-color: #e3e3e3;
}
.soria .dojoxRollingListPane .dojoxRollingListItemSelected {
	color: #243C5F;
	background-color: #ccc;
	font-weight: bold;
}
.soria .dojoxRollingListPaneCurrentSelected .dojoxRollingListItemSelected {
	background-color: #d9e6f9;
}
.soria .dojoxRollingListPane .dojoxRollingListItemHoverSelected,
.soria .dojoxRollingListPane .dojoxRollingListItemFocusSelected {
	background-color: #ecf3fc;
}
.soria .dojoxRollingListItem {
	font-family: inherit;
}
.nihilo .dojoxRollingList {
	border-color: #d3d3d3;
}
.nihilo .dijitPopup .dojoxRollingList {
	border-color: #b3b3b3;
}
.nihilo .dojoxRollingListPane {
	background-color: #fff;
}
.nihilo .dojoxRollingListPane .dojoxRollingListItemHover,
.nihilo .dojoxRollingListPane .dojoxRollingListItemFocus {
	background-color: #e3e3e3;
}
.nihilo .dojoxRollingListPane .dojoxRollingListItemSelected {
	color: #243C5F;
	background-color: #ccc;
	font-weight: bold;
}
.nihilo .dojoxRollingListPaneCurrentSelected .dojoxRollingListItemSelected {
	background-color: #ffe284;
}
.nihilo .dojoxRollingListPane .dojoxRollingListItemHoverSelected,
.nihilo .dojoxRollingListPane .dojoxRollingListItemFocusSelected {
	background-color: #fff1c2;
}
.nihilo .dojoxRollingListItem {
	font-family: inherit;
}
.dojoxFileInfoPane *{
	white-space: normal;
}
.dojoxFileInfoLabel {
	font-weight: bold;
	white-space: nowrap;
}
.dojoxFileInfoPane {
	width: 20em;
}
.tundra .dojoxFilePickerItem .dijitMenuItemIcon {
	background-image: url("images/tundraFileIcons.gif");
	background-repeat: no-repeat;
}
.tundra .dojoxFilePickerItem .dojoxEmpty {
	background-image: none;
}
.tundra .dojoxFilePickerItem .dojoxDirectoryItemIcon {
	background-position: 0px;
}
.tundra .dojoxFilePickerItemSelected .dojoxDirectoryItemIcon {
	background-position: -16px;
}
.tundra .dojoxFilePickerItem .dojoxFileItemIcon {
	background-position: -32px;
}
.tundra .dojoxFilePickerItemSelected .dojoxFileItemIcon {
	background-position: -48px;
}
.soria .dojoxFilePickerItem .dijitMenuItemIcon {
	background-image: url("images/soriaFileIcons.gif");
	background-repeat: no-repeat;
}
.soria .dojoxFilePickerItem .dojoxEmpty {
	background-image: none;
}
.soria .dojoxFilePickerItem .dojoxDirectoryItemIcon {
	background-position: 0px;
}
.soria .dojoxFilePickerItemSelected .dojoxDirectoryItemIcon {
	background-position: -16px;
}
.soria .dojoxFilePickerItem .dojoxFileItemIcon {
	background-position: -32px;
}
.soria .dojoxFilePickerItemSelected .dojoxFileItemIcon {
	background-position: -48px;
}
.nihilo .dojoxFilePickerItem .dijitMenuItemIcon {
	background-image: url("images/nihiloFileIcons.gif");
	background-repeat: no-repeat;
}
.nihilo .dojoxFilePickerItem .dojoxEmpty {
	background-image: none;
}
.nihilo .dojoxFilePickerItem .dojoxDirectoryItemIcon {
	background-position: 0px;
}
.nihilo .dojoxFilePickerItemSelected .dojoxDirectoryItemIcon {
	background-position: -16px;
}
.nihilo .dojoxFilePickerItem .dojoxFileItemIcon {
	background-position: -32px;
}
.nihilo .dojoxFilePickerItemSelected .dojoxFileItemIcon {
	background-position: -48px;
}
