
.soria .dijitInputField INPUT,
.soria .dijitTextBox,
.soria .dijitComboBox,
.soria .dijitSpinner {
	margin: 0em 0.1em;
}
.soria .dijitTextBox,
.soria .dijitComboBox,
.soria .dijitSpinner,
.soria .dijitInlineEditor input,
.soria .dijitTextArea {
	
	background:#fff url("../images/validationInputBg.png") repeat-x top left;
	border:1px solid #8ba0bd;
	line-height: normal;
}
.dj_ie6 .soria .dijitTextBox,
.dj_ie6 .soria .dijitComboBox,
.dj_ie6 .soria .dijitSpinner,
.dj_ie6 .soria .dijitInlineEditor input,
.dj_ie6 .soria .dijitTextArea {
	background:#fff url('../images/validationInputBg.gif') repeat-x top left;
}
.soria .dijitComboBox .dijitButtonNode {
	padding: 0 0.2em;
}
.soria .dijitComboBox .dijitButtonNode,
.soria .dijitSpinner .dijitButtonNode {
	
	border-color: #8ba0bd;
	border-left: 1px solid #8ba0bd;
}
.soria .dijitTextBoxFocused,
.soria .dijitComboBoxFocused,
.soria .dijitSpinnerFocused, .soria .dijitSpinnerUpArrowActive, .soria .dijitSpinnerDownArrowActive,
.soria .dijitTextAreaFocused {
	
	border-color:#406b9b;
}
.soria .dijitComboBoxFocused .dijitButtonNode,
.soria .dijitSpinnerFocused .dijitButtonNode,
.soria .dijitSpinnerUpArrowActive .dijitButtonNode,
.soria .dijitSpinnerDownArrowActive .dijitButtonNode {
	border-left-color:#8ba0bd;
}
.soria .dijitSpinnerFocused .dijitDownArrowButton,
.soria .dijitSpinnerUpArrowActive .dijitDownArrowButton,
.soria .dijitSpinnerDownArrowActive .dijitDownArrowButton {
	border-top-color:#8ba0bd;
}
.soria .dijitError {
	border-color:#f3d118;
	background-color:#f9f7ba;
	background-image:none;
}
.dj_ie6 .soria .dijitError INPUT {
	
	background-color:#f9f7ba !important;
}
.soria .dijitErrorFocused {
	background-color:#ff6;
	background-image:none;
}
.dj_ie6 .soria .dijitErrorFocused INPUT {
	
	background-color:#ff6 !important;
}
.soria .dijitValidationIcon {
	
	width: 16px;
	background: transparent url('../images/warning.png') no-repeat center center;
}
.soria .dijitComboBoxHighlightMatch {
	background-color:#f9f7ba;
}
