
.nihilo .dijitButtonNode {
	
	
	border:1px solid #dedede;
	border-bottom:1px solid #dedede;
	padding: 0.1em 0.2em 0.2em 0.2em;
	background: #fff url("../images/buttonEnabled.png") repeat-x top left;
}
.nihilo .dijitSelect .dijitButtonContents {
	border-right: none;
}
.nihilo .dijitButtonNode button {
	border: 0px;
	background-color: transparent;
}
.nihilo .dijitButtonText {
	text-align: center;
	padding: 0 0.3em;
}
.nihilo .dijitComboBox .dijitButtonNode {
	border-width: 0px 0px 0px 1px;
}
.nihilo .dijitArrowButton {
	color: #111;
}
.nihilo .dijitComboButton .dijitDownArrowButton {
	padding-right:4px;
}
.nihilo .dijitComboBoxReadOnly,
.nihilo .dijitSpinnerReadOnly,
.nihilo .dijitSpinnerReadOnly .dijitButtonNode,
.nihilo .dijitButtonDisabled .dijitButtonNode,
.nihilo .dijitToggleButtonDisabled .dijitButtonNode,
.nihilo .dijitDropDownButtonDisabled .dijitButtonNode,
.nihilo .dijitComboButtonDisabled .dijitButtonNode,
.nihilo .dijitComboBoxDisabled,
.nihilo .dijitSpinnerDisabled,
.nihilo .dijitSpinnerDisabled .dijitButtonNode {
	
	border-color: #dedede;
	background:#fafafa url("../images/buttonDisabled.png") top repeat-x;
	opacity: 0.60;
}
.dj_ie6 .nihilo .dijitComboButtonDisabled .dijitButtonText {
	
	color: #aaa;
}
.nihilo .dijitButtonHover .dijitButtonNode,
.nihilo .dijitButtonNodeHover,
.nihilo .dijitToggleButtonHover .dijitButtonNode,
.nihilo .dijitDropDownButtonHover .dijitButtonNode,
.nihilo .dijitComboButtonHover .dijitButtonContents,
.nihilo .dijitComboButtonDownArrowHover .dijitDownArrowButton,
.nihilo .dijitComboBoxHover .dijitDownArrowButton,
.nihilo .dijitSpinnerUpArrowHover .dijitUpArrowButton,
.nihilo .dijitSpinnerDownArrowHover .dijitDownArrowButton {
	
	
	color:#243C5F;
	background:#fcfcfc url("../images/buttonHover.png") repeat-x top left;
}
.nihilo .dijitSpinnerUpArrowActive .dijitUpArrowButton,
.nihilo .dijitSpinnerDownArrowActive .dijitDownArrowButton,
.nihilo .dijitButtonActive .dijitButtonNode,
.nihilo .dijitToggleButtonActive .dijitButtonNode,
.nihilo .dijitDropDownButtonActive .dijitButtonNode,
.nihilo .dijitComboButtonActive .dijitButtonContents,
.nihilo .dijitDownArrowActive .dijitDownArrowButton,
.nihilo .dijitComboBoxActive .dijitDownArrowButton,
.nihilo .dijitStackController .dijitToggleButtonChecked .dijitButtonNode {
	
	border-color:#dedede;
	background: #f5f5f5 url("../images/buttonActive.png") top left repeat-x;
}
.nihilo .dijitArrowButtonInner {
	background-image: url("../images/spriteArrows.png");
	background-repeat: no-repeat;
	background-position: 0px top;
	width: 11px;
}
.nihilo .dijitLeftArrowButton .dijitArrowButtonInner {
	background-position: -11px top;
}
.nihilo .dijitUpArrowButton .dijitArrowButtonInner {
	background-position: -22px top;
}
.nihilo .dijitRightArrowButton .dijitArrowButtonInner {
	background-position: -33px top;
}
.dj_ie6 .nihilo .dijitArrowButtonInner {
	background-image: url("../images/spriteArrows.gif");
}
