
.nihilo .dijitAccordionContainer {
	border-color: #ccc;
	background-color: #fff;
}
.nihilo .dijitAccordionTitle {
	background:#fafafa url("../images/titleBar.png") repeat-x top left;
	border-top: 1px solid #dedede;
	padding: 5px 4px 6px 8px;
	cursor:pointer;
	font-size: 0.9em;
	font-weight: bold;
	color: #6d6d6d;
}
.nihilo .dijitAccordionTitle-selected  {
	background: #f9f9f9 url("../images/accordionItemActive.png") top repeat-x;
	font-weight: bold;
	border-top: 1px solid #dedede;
	border-bottom: 1px solid #dedede;
	padding: 5px 4px 5px 8px;
	cursor: default;
	color: #243C5F;
}
.nihilo .dijitAccordionArrow {
	background:url("../images/spriteRoundedIconsSmall.gif") no-repeat -30px top;
	width:15px;
	height:15px;
	margin-top:-1px;
}
.nihilo .dijitAccordionTitle-selected .dijitAccordionArrow {
	background:url("../images/spriteRoundedIconsSmall.gif") no-repeat -15px top;
	margin-top:-1px;
}
.nihilo .dijitAccordionText {
	margin-left: 4px;
	margin-right: 4px;
}
