.dojoxFloatingPane {
	background-color:#fff;
	position:relative; 
	border: 1px solid #dedede; 
	overflow: hidden;
	-webkit-box-shadow: 0px 5px 10px #adadad;
}
.dojoxFloatingPaneFg {
	-webkit-box-shadow: 0px 8px 20px #525252;
}
.dojoxFloatingPaneTitle {
	background: #cccccc;
	background:#fafafa repeat-x bottom left;
	border:1px solid #bfbfbf;
	padding:4px 4px 2px 4px;
	cursor: pointer;
	white-space: nowrap;
}
.soria .dojoxFloatingPaneTitle {
	background:#fff url("../../../dijit/themes/soria/images/titleBar.png") repeat-x top left;
	border:1px solid #b1badf;
	font-size: 0.9em;
	font-weight: bold;
	line-height:1.2em;
}
.tundra .dojoxFloatingPaneTitle {
	background:#fafafa url("../../../dijit/themes/tundra/images/titleBarBg.gif") repeat-x bottom left;
	border:1px solid #bfbfbf;
	color:#000; 	
}
.dojoxFloatingCloseIcon {
	background:url('../../../dijit/themes/tundra/images/tabClose.png') no-repeat center center; 
	width:16px;
	height:16px; 
	overflow:hidden;
	float:right; 
}
.dojoxFloatingMinimizeIcon {
	background:url('../../../dijit/themes/tundra/images/spriteArrows.png') no-repeat 0px center; 
	width:7px;
	margin: 0px 4px;
	overflow:hidden;
	float:right; 
}
.soria .dojoxFloatingMinimizeIcon {
	background:url("../../../dijit/themes/soria/images/spriteRoundedIconsSmallBl.png") no-repeat -15px top;
	width: 14px;
	margin: 0px 2px;
}
.floatingPaneMaximized .dojoxFloatingMaximizeIcon { display:none; }
.dojoxFloatingMaximizeIcon {
	background:url('../../../dijit/themes/tundra/images/spriteArrows.png') no-repeat -21px center;
	width:7px;
	margin: 0px 4px;
	overflow:hidden;
	float:right;	
}
.soria .dojoxFloatingMaximizeIcon {
	background:url("../../../dijit/themes/soria/images/spriteRoundedIconsSmallBl.png") no-repeat -45px top;
}
.floatingPaneMaximized .dojoxFloatingRestoreIcon { display:inline; }
.dojoxFloatingRestoreIcon {
	background:url('../../../dijit/themes/tundra/images/spriteArrows.png') no-repeat 0px center; 
	width:7px;
	margin: 0px 4px;
	float:right;
	display:none;
}
.dojoxFloatingResizeHandle {
	background:url('icons/resize.png') no-repeat bottom right;
	position:absolute; 
	right:0; 
	bottom:0; 	
	width:16px;
	height:16px; 
	cursor:nw-resize;
}
.dojoxFloatingCloseIcon {
	width:15px;
	height:15px; 
	overflow:hidden;
	float:right; 
	cursor:pointer;
}
.soria .dojoxFloatingCloseIcon {
	background:url("../../../dijit/themes/soria/images/spriteRoundedIconsSmallBl.png") no-repeat -60px top;
}
.tundra .dojoxFloatingCloseIcon {
	background:url('../../../dijit/themes/tundra/images/tabClose.png') no-repeat center center; 	
}
.dojoxFloatingDockDefault {
	position:absolute;
	bottom:0px;
	left:0px;
	overflow:hidden; 
	margin:0;
	margin-bottom:3px; 
	padding:0px; 
	width:100%;
	z-index:99; 
	background:transparent;
	
}
.dojoxDockList {
	padding: 0px;
	margin: 0px;
}
.dojoxDockRestoreButton {
	background:url('../../../dijit/themes/tundra/images/arrowUp.png') no-repeat center center;
	width:16px; height:16px;
	overflow:hidden; 
	float:left;
	margin-top:2px; 
}
.soria .dojoxDockRestoreButton {
	background:url("../../../dijit/themes/soria/images/spriteRoundedIconsSmallBl.png") no-repeat -45px top;
}
.dojoxDockTitleNode {
	overflow:hidden;
}
.dojoxDock {
	display: block;
	border: 1px solid black;
	position: absolute;
	padding:0;
	margin:0;
	background:#fcfcfc;
}
.dojoxDockNode {
	border: 1px solid #adadad;
	border-radius: 2px;
	-webkit-border-radius: 2px;
	-moz-border-radius: 3px;
	cursor:pointer; 
	list-style: none;
	padding: 2px;
	margin: 0px;
	height: 16px;
	width: auto;
	float: left;
	background: #fafafa url("../../../dijit/themes/tundra/images/titleBarBg.gif") repeat-x bottom left;
}
.soria .dojoxDockNode {
	background:#b7cdee url("../../../dijit/themes/soria/images/titleBar.png") repeat-x;
}
.dojoxFloatingPaneContent {
	overflow: auto;
	background-color: #fff; 
	height: 100%; 
	width:	100%; 
}
.dojoxFloatingPaneCanvas {
	background-color:#fff;
}
