
.tundra .dijitButtonNode {
	
	border: 1px solid #c0c0c0;
	border-bottom: 1px solid #9b9b9b;
	padding: 0.1em 0.2em 0.2em 0.2em;
	background: #fff url("../images/buttonEnabled.png") repeat-x bottom left;
}
.tundra .dijitSelect .dijitButtonContents {
	border-right: none;
}
.dijitRtl .tundra .dijitSelect .dijitButtonContents {
	border-left: none;
	border-right-width: 1px;
}
.tundra .dijitButtonNode button {
	border: 0px;
	background-color: transparent;
}
.tundra .dijitButtonText {
	text-align: center;
	padding: 0 0.3em;
}
.tundra .dijitDisabled .dijitButtonText {
	color: #7F7F7F;
}
.tundra .dijitArrowButton {
	color: #111;
}
.tundra .dijitComboButton .dijitDownArrowButton {
	padding-right:4px;
}
.tundra .dijitComboBoxReadOnly,
.tundra .dijitSpinnerReadOnly,
.tundra .dijitSpinnerReadOnly .dijitButtonNode,
.tundra .dijitButtonDisabled .dijitButtonNode,
.tundra .dijitToggleButtonDisabled .dijitButtonNode,
.tundra .dijitDropDownButtonDisabled .dijitButtonNode,
.tundra .dijitComboButtonDisabled .dijitButtonNode,
.tundra .dijitComboBoxDisabled,
.tundra .dijitSpinnerDisabled,
.tundra .dijitSpinnerDisabled .dijitButtonNode {
	
	
	border-color: #d5d5d5 #d5d5d5 #bdbdbd #d5d5d5;
	background:#e4e4e4 url("../images/buttonDisabled.png") top repeat-x;
}
.tundra .dijitButtonHover .dijitButtonNode,
.tundra .dijitButtonNodeHover,
.tundra .dijitToggleButtonHover .dijitButtonNode,
.tundra .dijitDropDownButtonHover .dijitButtonNode,
.tundra .dijitComboButtonHover .dijitButtonContents,
.tundra .dijitComboButtonDownArrowHover .dijitArrowButton {
	
	
	border-color: #a5beda;
	border-bottom-color:#5c7590;
	color:#243C5F;
	background:#fcfdff url("../images/buttonHover.png") repeat-x bottom;
}
.tundra .dijitComboBoxHover .dijitDownArrowButton,
.tundra .dijitSpinnerUpArrowHover .dijitUpArrowButton,
.tundra .dijitSpinnerDownArrowHover .dijitDownArrowButton {
	
	color:#243C5F;
	background:#fcfdff url("../images/buttonHover.png") repeat-x bottom;
}
.tundra .dijitSpinnerUpArrowActive .dijitUpArrowButton,
.tundra .dijitSpinnerDownArrowActive .dijitDownArrowButton,
.tundra .dijitButtonActive .dijitButtonNode,
.tundra .dijitToggleButtonActive .dijitButtonNode,
.tundra .dijitDropDownButtonActive .dijitButtonNode,
.tundra .dijitComboButtonActive .dijitButtonContents,
.tundra .dijitDownArrowActive .dijitDownArrowButton,
.tundra .dijitComboBoxActive .dijitDownArrowButton,
.tundra .dijitStackController .dijitToggleButtonChecked .dijitButtonNode {
	
	border-color:#366dba;
	background: #ededed url("../images/buttonActive.png") bottom repeat-x;
}
.tundra .dijitArrowButtonInner {
	background:url("../images/spriteArrows.png") no-repeat scroll 0px center;
	width: 7px;
	height: 7px;
	font-size: 1px;
	margin: 0px 4px 0px 5px;
}
.dj_ie6 .tundra .dijitArrowButtonInner {
	background-image:url("../images/spriteArrows.gif");
}
.tundra .dijitLeftArrowButton .dijitArrowButtonInner {
	background-position: -7px center;
}
.tundra .dijitRightArrowButton .dijitArrowButtonInner {
	background-position: -14px center;
}
.tundra .dijitUpArrowButton .dijitArrowButtonInner {
	background-position: -21px center;
}
.tundra .dijitDisabled .dijitArrowButtonInner {
	background-position: -28px center;
}
.tundra .dijitDisabled .dijitLeftArrowButton .dijitArrowButtonInner {
	background-position: -35px center;
}
.tundra .dijitDisabled .dijitRightArrowButton .dijitArrowButtonInner {
	background-position: -42px center;
}
.tundra .dijitDisabled .dijitUpArrowButton .dijitArrowButtonInner {
	background-position: -49px center;
}
.tundra .dijitComboBox .dijitArrowButton .dijitArrowButtonInner {
	height: auto;
	font-size: 100%;
	font-size: inherit;
}
.tundra .dijitComboBoxHover .dijitArrowButtonInner {
	
}
.tundra .dijitSpinner .dijitArrowButtonInner {
	display: block;  
	position:absolute;
	top: 50%;
	margin-top: -4px; 
	left: 50%;
	margin-left: -4px; 
	line-height: 2px;
}
