
.dijitDialogUnderlay {
	background-color:#000; 
}
.dojoxLightbox {
	position:absolute;
	z-index:999;
	overflow:hidden;
	width:100px;
	height:100px; 
	border:11px solid #fff;
	background:#fff url('images/loading.gif') no-repeat center center;
        
	-webkit-box-shadow: 0px 6px 10px #636363; 
	-webkit-border-radius: 3px;
	-moz-border-radius:4px;
        border-radius: 4px;
}
.dojoxLightboxContainer {
	position:absolute;
	top:0; left:0; 
}
.dojoxLightboxFooter {
	padding-bottom:5px;
	position:relative;
	bottom:0;
	left:0;
	margin-top:8px;
	color:#333;
	z-index:1000;
	font-size:10pt;
}
.dojoxLightboxGroupText {
	color:#666; 
	font-size:8pt;
}
.LightboxNext,
.LightboxPrev,
.LightboxClose {
	float:right;
	width:16px;
	height:16px;
	cursor:pointer;
}
.nihilo .LightboxClose,
.tundra .LightboxClose {
	background:url('images/close.png') no-repeat center center;
}
.di_ie6 .nihilo .LightboxClose,
.dj_ie6 .tundra .LightboxClose {
	background:url('images/close.gif') no-repeat center center;
}
.nihilo .LightboxNext,
.tundra .LightboxNext {
	background:url('images/right.png') no-repeat center center;
}
.dj_ie6 .nihilo .LightboxNext,
.dj_ie6 .tundra .LightboxNext {
	background:url('images/right.gif') no-repeat center center;
}
.nihilo .LightboxPrev,
.tundra .LightboxPrev {
	background:url('images/left.png') no-repeat center center;
}
.dj_ie6 .nihilo .LightboxPrev,
.dj_ie6 .tundra .LightboxPrev {
	background:url('images/left.gif') no-repeat center center;
}
.soria .LightboxClose,
.soria .LightboxNext,
.soria .LightboxPrev {
	width:15px;
	height:15px;
	background:url('../../../dijit/themes/soria/images/spriteRoundedIconsSmall.png') no-repeat center center;
	background-position:-60px;
}
.soria .LightboxNext {
	background-position:-30px 0;
}
.soria .LightboxPrev {
	background-position:0 0;
}
