/*
	Copyright (c) 2004-2009, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/


if(!dojo._hasResource["dojox.timing"]){
dojo._hasResource["dojox.timing"]=true;
dojo.provide("dojox.timing");
dojo.require("dojox.timing._base");
}
