
.dojoxBadge {
	position:relative;
}
.dojoxBadge .dojoxBadgeImage {
	position:absolute;
	top:0; left:0;
	margin:0;
	padding:0;
}
.dojoxBadge {
	margin:0; padding:0;
	border:1px solid #eee;
}
.dojoxBadge .dojoxBadgeImage {
	overflow:hidden;
	margin-left:1px;
	margin-top:1px;
	background:#ededed;
	z-index:90;
}
.dojoxBadge .dojoxBadgeSeen {
	background-color:#dedede;
}
.dojoxBadge .dojoxBadgeOver {
	background-color:green !important;
}
.dojoxBadge .dojoxBadgeTop {
	z-index:99;
}
