({"backwards":"Backwards","findReplace":"Toggle Find/Replace","replaceAll":"All Occurances","replaceDialogText":"Replaced ${0} occurances.","replaceButton":"Replace","findButton":"Find","findLabel":"Find what:","matchCase":"Match Case","replaceLabel":"Replace with:"})