
.tundra .dijitAccordionContainer {
	border-color: #ccc;
	background-color: #fff;
}
.tundra .dijitAccordionTitle {
	background:#fafafa url("../images/titleBar.png") repeat-x bottom left;
	border-top: 1px solid #bfbfbf;
	padding: 4px 4px 4px 8px;
	cursor:pointer;
}
.tundra .dijitAccordionTitle-hover  {
	background: #f8fafd url("../images/accordionItemHover.gif") bottom repeat-x;
}
.tundra .dijitAccordionTitle-selected  {
	background: #f9f9f9 url("../images/accordionItemActive.gif") bottom repeat-x;
	font-weight: bold;
	border-top: 1px solid #aaaaaa;
	border-bottom: 1px solid #bfbfbf;
	padding: 4px 4px 4px 8px;
	cursor: default;
}
