({"buttonSet":"ตั้งค่า","insertTableTitle":"แทรกตาราง","insertTableRowAfterLabel":"เพิ่มแถวหลัง","center":"กึ่งกลาง","deleteTableColumnLabel":"ลบคอลัมน์","right":"ขวา","insertTableColumnBeforeLabel":"เพิ่มคอลัมน์ก่อน","tableWidth":"ความกว้างของตาราง:","buttonInsert":"แทรก","default":"ดีฟอลต์","align":"จัดตำแหน่ง:","insertTableRowBeforeLabel":"เพิ่มแถวก่อน","cellSpacing":"ระยะห่างเซลล์:","pixels":"พิกเซล","selectTableLabel":"เลือกตาราง","rows":"แถว:","modifyTableTitle":"ปรับเปลี่ยนตาราง","cellPadding":"ส่วนเสริมเซลล์:","deleteTableRowLabel":"ลบแถว","backgroundColor":"สีพื้นหลัง:","insertTableColumnAfterLabel":"เพิ่มคอลัมน์หลัง","left":"ซ้าย","borderThickness":"ความหนาเส้นขอบ","columns":"คอลัมน์:","percent":"เปอร์เซ็นต์","borderColor":"สีเส้นขอบ:"})