.dijitRtl .tundra .dijitTab {
	-moz-box-orient:horizontal;
	text-align: right;
}
.dijitRtl .tundra .dijitTabInnerDiv {
	padding:2px 9px 2px 8px;
}
.dijitRtl .tundra .tabStrip-disabled .tabStripButton .dijitTabInnerDiv {
	padding-bottom: 3px;
	padding-top: 1px;
}
.dijitRtl .tundra .tabStripButton .dijitTabInnerDiv {
	padding: 3px 2px 4px 2px;
}
.dijitRtl .tundra .dijitTabPaneWrapper {
	#zoom: 1;
}
.dj_ie-rtl .tundra .dijitTabContainerLeft-tabs {
	margin-left: 1px !important;
}
.dj_ie-rtl .tundra .dijitTabContainerRight-tabs {
	margin-right: 1px !important;
}
.dijitRtl .tundra .dijitTabContainerLeft-tabs .dijitTab,
.dijitRtl .tundra .dijitTabContainerRight-tabs .dijitTab {
	margin-left:0px;
}
.dj_ie-rtl .tundra .dijitTab .dijitTabInnerDiv {
	
	width : 0.1% !important;
}
