
.tundra .dijitSelectDisabled * {
    cursor: not-allowed !important;
}
.tundra .dijitSelectReadOnly * {
    cursor: default !important;
}
.tundra .dijitSelect .dijitButtonNode {
	padding: 0px;
}
.tundra .dijitSelect .dijitButtonContents {
	padding-top: 1px;
    background:#fff url("../images/validationInputBg.png") repeat-x top left;
    #background:#fff url('../images/validationInputBg.gif') repeat-x top left;
}
.tundra .dijitSelectHover .dijitButtonContents,
.tundra .dijitSelectActive .dijitButtonContents,
.tundra .dijitSelectOpened .dijitButtonContents,
.tundra .dijitSelectDisabled .dijitButtonContents,
.tundra .dijitSelectReadOnly .dijitButtonContents{
	background: transparent none;
}
.dj_ie .tundra .dijitSelect .dijitButtonContents {
	padding-top: 0px;
}
.tundra .dijitSelectDisabled .dijitButtonNode {
    border-color: #d5d5d5 #bdbdbd #bdbdbd #d5d5d5;
    background:#e4e4e4 url("../images/buttonDisabled.png") top repeat-x;
}
.dj_ie .tundra .dijitSelectDisabled  .dijitButtonNode * {
	filter: gray() alpha(opacity=50);
}
.tundra .dijitSelectHover .dijitButtonNode {
    border-color:#a5beda;
    border-bottom-color:#5c7590;
    border-right-color:#5c7590;
    color:#243C5F;
    background:#fcfdff url("../images/buttonHover.png") repeat-x bottom;
}
.tundra .dijitSelectActive .dijitButtonNode,
.tundra .dijitSelectOpened .dijitButtonNode {
    border-color:#366dba;
    background: #ededed url("../images/buttonActive.png") bottom repeat-x;
}
.tundra .dijitSelectMenu td {
	padding: 0em;
}
.tundra .dijitSelectMenu .dijitMenuItemIcon {
	margin: 0.1em 0.2em;
	display: none;
}
.tundra .dijitSelectMenu .dijitMenuItemLabel,
.tundra .dijitSelectMenu .dijitMenuArrowCell {
	padding: 0.1em 0.2em;
}
