({"backwards":"뒷방향으로","findReplace":"찾기/바꾸기 토글","replaceAll":"모두 바꾸기","replaceDialogText":"${0} 개의 내용이 변경되었습니다.","replaceButton":"바꾸기","findButton":"찾기","findLabel":"찾을 내용:","matchCase":"대소문자 구분","replaceLabel":"바꿀 내용:"})