({"buttonSet":"Ayarla","insertTableTitle":"Tablo Ekle","insertTableRowAfterLabel":"Satırı Arkasına Ekle","center":"orta","deleteTableColumnLabel":"Sütunu Sil","right":"sağ","insertTableColumnBeforeLabel":"Sütunu Önüne Ekle","tableWidth":"Tablo Genişliği","buttonInsert":"Ekle","default":"varsayılan","align":"Hizala:","insertTableRowBeforeLabel":"Satırı Önüne Ekle","cellSpacing":"Hücre Aralığı:","pixels":"piksel","selectTableLabel":"Tablo Seç","rows":"Satırlar:","modifyTableTitle":"Tabloyu Değiştir","cellPadding":"Hücre Doldurma:","deleteTableRowLabel":"Satırı Sil","backgroundColor":"Arka Plan Rengi:","insertTableColumnAfterLabel":"Sütunu Arkasına Ekle","left":"sol","borderThickness":"Kenarlık Kalınlığı","columns":"Sütunlar:","percent":"yüzde","borderColor":"Kenarlık Rengi: "})