/*
	Copyright (c) 2004-2009, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/


if(!dojo._hasResource["dojox.dtl.contrib.html"]){
dojo._hasResource["dojox.dtl.contrib.html"]=true;
dojo.provide("dojox.dtl.contrib.html");
dojo.require("dojox.dtl.contrib.dom");
dojo.deprecated("dojox.dtl.html","All packages and classes in dojox.dtl that start with Html or html have been renamed to Dom or dom");
}
