.dojoxUploaderNorm{
	font-family:Myriad,Helvetica,Tahoma,Arial,clean,sans-serif;
	font-size:12px;
	border: 1px solid #c0c0c0; 
	border-bottom: 1px solid #9b9b9b; 
	padding: 0.1em 0.2em 0.2em 0.2em; 
	background: #fff url("../../../dijit/themes/tundra/images/buttonEnabled.png") repeat-x bottom left;
	
	vertical-align: middle;
	
	margin:0;
	line-height:normal;
	text-align:center;
	white-space: nowrap;
	
	cursor: pointer;
}
.uploaderInsideNode{
	visibility:hidden;
}
.dojoxUploaderHover{
	border-color:		#a5beda; 
	border-bottom-color:#5c7590; 
	color:#243C5F;
	background:#fcfdff url("../../../dijit/themes/tundra/images/buttonHover.png") repeat-x bottom;
}
.dojoxUploaderActive{
	border-color:#366dba;
	background: #ededed url("../../../dijit/themes/tundra/images/buttonActive.png") bottom repeat-x;
}
.dojoxUploaderDisabled{
	color: #7F7F7F;
	border-color: #d5d5d5 #d5d5d5 #bdbdbd #d5d5d5; 
	background:#e4e4e4 url("../../../dijit/themes/tundra/images/buttonDisabled.png") top repeat-x;
}
.soria .dojoxUploaderNorm {
	border: 1px solid #8ba0bd;
	border-bottom:1px solid #657c9c;
	padding: 0.1em 0.2em 0.2em 0.2em; 
	background: #bcd5f0 url("../../../dijit/themes/soria/images/buttonEnabled.png") repeat-x top left;
}
.soria .dojoxUploaderHover{
	color:#243C5F;
	background:#acc5e2 url("../../../dijit/themes/soria/images/buttonHover.png") repeat-x top left !important;
}
.soria .dojoxUploaderActive{
	border-color:#657c9c;
	background: #91b4e5 url("../../../dijit/themes/soria/images/buttonActive.png") top left repeat-x !important;
}
.soria .dojoxUploaderDisabled{
	border-color: #b9bbdd #b9bbdd #b9bbdd #b9bbdd;
	background:#c3d3e5 url("../../../dijit/themes/soria/images/buttonDisabled.png") top repeat-x !important;
	opacity: 0.60;
}
.nihilo .dojoxUploaderNorm {
	border:1px solid #dedede;
	border-bottom:1px solid #dedede;
	padding: 0.1em 0.2em 0.2em 0.2em; 
	background: #fff url("../../../dijit/themes/nihilo/images/buttonEnabled.png") repeat-x top left;
}
.nihilo .dojoxUploaderHover{
	color:#243C5F;
	background:#fcfcfc url("../../../dijit/themes/nihilo/images/buttonHover.png") repeat-x top left !important;
}
.nihilo .dojoxUploaderActive{
	border-color:#dedede;
	background: #f5f5f5 url("../../../dijit/themes/nihilo/images/buttonActive.png") top left repeat-x !important;
}
.nihilo .dojoxUploaderDisabled{
	border-color: #dedede;
	background:#fafafa url("../../../dijit/themes/nihilo/images/buttonDisabled.png") top repeat-x !important;
	opacity: 0.60;
}
.noir .dojoxUploaderNorm {
	vertical-align:top;
	height:30px;
	font-family:inherit;
	font-size:inherit;
	background-color:transparent;
	background-image:none;
	padding:0px !important;
	line-height:25px;	
	color:#cccccc;
}
.noir .dojoxUploaderHover{
	color:#fa4242;
}
.noir .dojoxUploaderActive{
	color:#31d397;
}
.noir .dojoxUploaderDisabled{
	color:#3f3f3f;
}
.fileToUpload,
.fileToUploadClose,
.fileToUploadName,
.fileToUploadSize{
	height:18px;
	line-height:18px;
}
.fileToUpload{
	font-size:12px;
	font-family:sans-serif;
	padding:2px;
	margin:0px;
	width:100%;
}
.fileToUploadName{
	text-align:left;
	width:auto !important;
}
.fileToUploadSize{
	width:30px !important;
	text-align:right;
}
.dj_ie .fileToUploadSize{
	padding-right:20px;
}
.fileToUploadClose{
	background:url(../../../dijit/themes/tundra/images/tabClose.png) no-repeat 2px center;
	width:18px !important;
	cursor:pointer;
}
.fileToUploadClose:hover{
	background:url(../../../dijit/themes/tundra/images/tabCloseHover.png) no-repeat 2px center;
}
.thumb{
	height:50px;
	padding:3px;
	border:1px solid #ccc;
	margin-bottom:3px;
}
.thumbPic{
	width:50px;
	height:50px;
	text-align:center;
	line-height:50px;
	background-color:#000;
	float:left;
}
.thumbPic img{
	line-height:50px;
	margin:auto auto;
	display:block;
}
.thumbText{
	float:left;
	margin-left:5px;
	font-size:10px;
}
.dj_ie object{
	
	display:block !important;
}
