
.nihilo .dijitSelectDisabled * {
    cursor: not-allowed !important;
}
.nihilo .dijitSelectReadOnly * {
    cursor: default !important;
}
.nihilo .dijitSelect .dijitButtonNode {
	padding: 0px;
}
.nihilo .dijitSelect .dijitButtonContents {
	padding-top: 1px;
    background:#fff url("../images/validationInputBg.png") repeat-x top left;
    #background:#fff url('../images/validationInputBg.gif') repeat-x top left;
}
.nihilo .dijitSelectHover .dijitButtonContents,
.nihilo .dijitSelectActive .dijitButtonContents,
.nihilo .dijitSelectOpened .dijitButtonContents,
.nihilo .dijitSelectDisabled .dijitButtonContents,
.nihilo .dijitSelectReadOnly .dijitButtonContents{
	background: transparent none;
}
.dj_ie .nihilo .dijitSelect .dijitButtonContents {
	padding-top: 0px;
}
.nihilo .dijitSelectDisabled .dijitButtonNode {
    border-color: #dedede;
    background:#fafafa url("../images/buttonDisabled.png") top repeat-x;
}
.dj_ie .nihilo .dijitSelectDisabled  .dijitButtonNode * {
	filter: gray() alpha(opacity=50);
}
.nihilo .dijitSelectHover .dijitButtonNode {
    color:#000;
    background:#fcfcfc url("../images/buttonHover.png") repeat-x top left;
}
.nihilo .dijitSelectActive .dijitButtonNode,
.nihilo .dijitSelectOpened .dijitButtonNode {
    border-color:#dedede;
    background: #f5f5f5 url("../images/buttonActive.png") top left repeat-x;
}
.nihilo .dijitSelectMenu td {
	padding: 0em;
}
.nihilo .dijitSelectMenu .dijitMenuItemIcon {
	margin: 0.1em 0.2em;
	display: none;
}
.nihilo .dijitSelectMenu .dijitMenuItemLabel,
.nihilo .dijitSelectMenu .dijitMenuArrowCell {
	padding: 0.1em 0.2em;
}
