
.soria .dijitContentPane {
    padding: 0px;
}
.soria .dijitTabContainerTop-dijitContentPane,
.soria .dijitTabContainerLeft-dijitContentPane,
.soria .dijitTabContainerBottom-dijitContentPane,
.soria .dijitTabContainerRight-dijitContentPane,
.soria .dijitAccordionContainer-dijitContentPane {
    background-color: #fff;
    padding: 5px;
}
.soria .dijitSplitContainer-dijitContentPane,
.soria .dijitBorderContainer-dijitContentPane {
    background-color: #fff;		
    padding: 5px;
}
