({"buttonSet":"Definir","insertTableTitle":"Inserir tabela","insertTableRowAfterLabel":"Adicionar linha depois","center":"centro","deleteTableColumnLabel":"Eliminar coluna","right":"direita","insertTableColumnBeforeLabel":"Adicionar coluna antes","tableWidth":"Largura da tabela:","buttonInsert":"Inserir","default":"predefinição","align":"Alinhar:","insertTableRowBeforeLabel":"Adicionar linha antes","cellSpacing":"Espaçamento de células:","pixels":"píxeis","selectTableLabel":"Seleccionar tabela","rows":"Linhas:","modifyTableTitle":"Modificar tabela","cellPadding":"Preenchimento de células:","deleteTableRowLabel":"Eliminar linha","backgroundColor":"Cor de segundo plano:","insertTableColumnAfterLabel":"Adicionar coluna depois","left":"esquerda","borderThickness":"Espessura do contorno","columns":"Colunas:","percent":"percentagem","borderColor":"Cor do contorno:"})