.dojoxRotatorContainer .dijitStackController,
.dojoxRotatorPager {
	position:absolute;
	z-index:3;
}
.dojoxRotatorContent {
	position:absolute;
	z-index:1;
}
.dojoxRotatorContainer {
	border:1px solid #9b9b9b;
}
.dojoxRotatorContainer .dijitStackController {
	right:5px;
	top:5px;
}
.dojoxRotatorContainer .dijitStackController .dijitToggleButtonChecked .dijitButtonNode {
	background-color:#000;
	background-image:none;
	color:#fff;
}
.dojoxRotatorContainer .dojoxRotatorPager{bottom:5px;right:5px;}
.rotatorIcons .dijitButton{margin:0;}
.rotatorIcons .dijitButtonNode{background:none !important;border:0 !important;padding:0 !important;}
.rotatorIcons .dijitButtonText{display:none;}
.rotatorIcons .previous,
.rotatorIcons .next,
.rotatorIcons .playPause,
.rotatorIcons .dijitToggleButtonChecked .playPause{background-image:url("icons/rotator.png");background-repeat:no-repeat;display:block;height:16px;width:16px;}
.rotatorIcons .previous{background-position:0 0;}
.rotatorIcons .dijitButtonHover .previous{background-position:0 -16px;}
.rotatorIcons .dijitButtonActive .previous{background-position:0 -32px;}
.rotatorIcons .next{background-position:-16px 0;}
.rotatorIcons .dijitButtonHover .next{background-position:-16px -16px;}
.rotatorIcons .dijitButtonActive .next{background-position:-16px -32px;}
.rotatorIcons .playPause{background-position:-32px 0;}
.rotatorIcons .dijitToggleButtonHover .playPause{background-position:-32px -16px;}
.rotatorIcons .dijitToggleButtonActive .playPause{background-position:-32px -32px;}
.rotatorIcons .dijitToggleButtonChecked .playPause{background-position:-48px 0;}
.rotatorIcons .dijitToggleButtonCheckedHover .playPause{background-position:-48px -16px;}
.rotatorIcons .dijitToggleButtonCheckedActive .playPause{background-position:-48px -32px;}
