({"buttonSet":"تحديد","insertTableTitle":"‏ادراج جدول‏","insertTableRowAfterLabel":"اضافة صف بعد","center":"توسيط","deleteTableColumnLabel":"حذف عمود","right":"لليمين","insertTableColumnBeforeLabel":"اضافة عمود قبل","tableWidth":"عرض الجدول:","buttonInsert":"‏ادراج‏","default":"المفترض","align":"محاذاة:","insertTableRowBeforeLabel":"اضافة صف قبل","cellSpacing":"تباعد الخانة:","pixels":"عنصر صورة","selectTableLabel":"تحديد جدول","rows":"الصفوف:","modifyTableTitle":"تعديل جدول","cellPadding":"ملء الخانة:","deleteTableRowLabel":"حذف صف","backgroundColor":"لون الخلفية:","insertTableColumnAfterLabel":"اضافة عمود بعد","left":"لليسار","borderThickness":"سمك الحدود","columns":"الأعمدة:","percent":"نسبة مئوية","borderColor":"لون الحدود:"})