<div class="feedViewerContainer" dojoAttachPoint="feedViewerContainerNode">
	<table cellspacing="0" cellpadding="0" class="feedViewerTable">
		<tbody dojoAttachPoint="feedViewerTableBody" class="feedViewerTableBody">
		</tbody>
	</table>
</div>
