/*
	Copyright (c) 2004-2009, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/


if(!dojo._hasResource["dojox.cometd.HttpChannels"]){
dojo._hasResource["dojox.cometd.HttpChannels"]=true;
dojo.provide("dojox.cometd.HttpChannels");
dojo.require("dojox.io.httpParse");
dojo.require("dojox.cometd.RestChannels");
dojox.cometd.HttpChannels=dojox.cometd.RestChannels;
}
