({"buttonSet":"Defineix","insertTableTitle":"Insereix taula","insertTableRowAfterLabel":"Afegeix fila després","center":"centrat","deleteTableColumnLabel":"Suprimeix columna","right":"dreta","insertTableColumnBeforeLabel":"Afegeix columna abans","tableWidth":"Amplada de taula:","buttonInsert":"Insereix","default":"default","align":"Alinea:","insertTableRowBeforeLabel":"Afegeix fila abans","cellSpacing":"Espaiat de cel·la:","pixels":"píxels","selectTableLabel":"Selecciona taula","rows":"Files:","modifyTableTitle":"Modifica taula","cellPadding":"Emplenat de cel·la:","deleteTableRowLabel":"Suprimeix fila","backgroundColor":"Color de fons:","insertTableColumnAfterLabel":"Afegeix columna després","left":"esquerra","borderThickness":"Gruix del contorn","columns":"Columnes:","percent":"percentatge","borderColor":"Color del contorn"})