
body, div, dl, dt, dd, li, h1, h2, h3, h4, h5, h6, pre, form, fieldset, input, textarea, p, blockquote, th, td {
	margin: 0;
	padding: 0;
}
fieldset, img {
	border: 0 none;
}
address, caption, cite, code, dfn, th, var {
	font-style: normal; 
	font-weight: normal;
}
caption, th {
	text-align: left;
}
q:before, q:after {
	content:"";
}
abbr, acronym {
	border:0;
}
body { 
	font: 12px Myriad,Helvetica,Tahoma,Arial,clean,sans-serif; 
	*font-size: 75%;
}
h1 {
	font-size: 1.5em; 
	font-weight: normal;
	line-height: 1em; 
	margin-top: 1em;
	margin-bottom:0;
}
h2 { 
	font-size: 1.1667em; 
	font-weight: bold; 
	line-height: 1.286em; 
	margin-top: 1.929em; 
	margin-bottom:0.643em;
}
h3, h4, h5, h6 {
	font-size: 1em; 
	font-weight: bold; 
	line-height: 1.5em; 
	margin-top: 1.5em; 
	margin-bottom: 0;
}
p { 
	font-size: 1em; 
	margin-top: 1.5em; 
	margin-bottom: 1.5em; 
	line-height: 1.5em;
}
blockquote { 
	font-size: 0.916em; 
	margin-top: 3.272em; 
	margin-bottom: 3.272em; 
	line-height: 1.636em; 
	padding: 1.636em; 
	border-top: 1px solid #ccc; 
	border-bottom: 1px solid #ccc;
}
ol li, ul li { 
	font-size: 1em; 
	line-height: 1.5em; 
	margin: 0;
}
pre, code { 
	font-size:115%;
	*font-size:100%;
	font-family: Courier, "Courier New"; 
	background-color: #efefef; 
	border: 1px solid #ccc;
}
pre { 
	border-width: 1px 0; 
	padding: 1.5em;
}
table {  font-size:100%; }
table.dojoTabular { 
	border-collapse: collapse; 
	border-spacing: 0; 
	border: 1px solid #ccc; 
	margin: 0 1.5em;
}
.dojoTabular th { 
	text-align: center; 
	font-weight: bold;
}
table.dojoTabular thead, table.dojoTabular tfoot { 
	background-color: #efefef; 
	border: 1px solid #ccc; 
	border-width: 1px 0; 
}
table.dojoTabular thead tr th,
table.dojoTabular thead tr td,
table.dojoTabular tbody tr td,
table.dojoTabular tfoot tr td { 
	padding: 0.25em 0.5em;
}
