
.nihilo .dijitProgressBar {
	margin:2px 0px 2px 0px;
}
.nihilo .dijitProgressBarEmpty{
	
	background:#fff url("images/progressBarEmpty.png") repeat-x center center;
	border-color: #f8d582 #f8d582 #f8d582 #f8d582;
}
.nihilo .dijitProgressBarTile{
	
	background:#f0f0f0 url("images/progressBarFull.png") repeat-x center center;
}
.nihilo .dijitProgressBarFull {
	border-right:1px solid #f8d582;
}
.nihilo .dijitProgressBarLabel {
	
	color:#293a4b;
}
.nihilo .dijitProgressBarIndeterminate .dijitProgressBarTile {
	
	background:#cad2de url("images/progressBarAnim.gif") repeat-x center center;
}
