
.tundra .dijitContentPane {
	padding: 0px;
}
.tundra .dijitTabContainerTop-dijitContentPane,
.tundra .dijitTabContainerLeft-dijitContentPane,
.tundra .dijitTabContainerBottom-dijitContentPane,
.tundra .dijitTabContainerRight-dijitContentPane,
.tundra .dijitAccordionContainer-dijitContentPane {
	background-color: #fff;
	padding: 5px;
}
.tundra .dijitSplitContainer-dijitContentPane,
.tundra .dijitBorderContainer-dijitContentPane {
	background-color: #fff;		
	padding: 5px;
}
