
.nihilo .dijitContentPane {
    padding: 0px;
}
.nihilo .dijitTabContainerTop-dijitContentPane,
.nihilo .dijitTabContainerLeft-dijitContentPane,
.nihilo .dijitTabContainerRight-dijitContentPane,
.nihilo .dijitTabContainerBottom-dijitContentPane,
.nihilo .dijitAccordionContainer-dijitContentPane {
    background-color: #fff;
    padding: 5px;
}
.nihilo .dijitSplitContainer-dijitContentPane,
.nihilo .dijitBorderContainer-dijitContentPane {
    background-color: #fff;		
    padding: 5px;
}
