
.thumbWrapper .thumbNav {
	background-repeat: no-repeat;	
	background-position: center;
	padding-top: 1px;
	width: 30px;
	height: 100%;
}
.thumbOuter {
	padding-bottom: 2px;
}
.thumbOuter.thumbHoriz {
	width: 500px;
	height: 85px;
}
.thumbOuter.thumbVert {
	width: 100px;
	height: 400px;
}
.thumbOuter .enabled {
	background: transparent url("images/buttons.png") no-repeat center center;
}
.dj_ie6 .thumbOuter .enabled { background-image: url("images/buttons.gif"); }
.thumbOuter .thumbNav img {
	width: 48px;
	height: 75px;
}
.thumbOuter .thumbClickable div {
	cursor: pointer;
}
.thumbOuter .prevHoriz {
	background-position: -96px 12px;
	position: relative;
	float: left;
	height: 100%;
}
.thumbOuter .nextHoriz {
	background-position: -144px 12px;
	position: relative;
	float: right;
	height: 100%;
}
.thumbOuter .prevVert {
	background-position: 0px 0px;
	height: 48px;
	width:48px;
	margin-left:24px;
}
.thumbOuter .nextVert {
	background-position: -48px 0px;
	height: 48px;
	width:48px;
	margin-left:24px;
}
.thumbWrapper img {
	height: 75px;
	max-width: 100px;
	width: expression(this.width > 100 ? 100: true);
}
.thumbWrapper .thumbNav .imageGalleryThumb {
	height: 50px;
}
.thumbWrapper .thumbNotifier {
	background-color: red;
	width: 0px;
	margin-left: 2px;
	height: 5px;
	font-size: 1%;
}
.thumbWrapper .thumbLoaded {
	background-color: transparent;	
}
.thumbScroller {
	overflow-x: hidden;
	overflow-y: hidden;
	text-align: center;
}
.thumbHoriz .thumbScroller {
	width: 500px;
	height: 85px;
	float: left;
}
.thumbVert .thumbScroller {
	height: 500px;
	width: 100px;	
}
.thumbWrapper {
	float: left;
}
.thumbVert .thumbWrapper {
	width: 100px;
	height: 10px;
}
.thumbHoriz .thumbWapper {
	height:85px;
	width: 10px;
}
.thumbWrapper.thumbHoriz div {
	float: left;
	padding-right: 2px;
}
.thumbWrapper.thumbVert {
	width: 100px;
}
.thumbWrapper.thumbVert div {
	padding-bottom: 2px;
}
