@CHARSET "ISO-8859-1";
.dojoxGaugeContent {
	font-family: Verdana;
	border-width: 1px;
	border-style: solid;
	border-color: #CCCCCC;
}
.dojoxGaugeRange1 {
	fill: #606060 ;
	stroke: #606060 ;
}
.dojoxGaugeRange2 {
	fill: #707070 ;
	stroke: #707070 ;
}
.dojoxGaugeRange3 {
	fill: #808080 ;
	stroke: #808080 ;
}
.dojoxGaugeRange4 {
	fill: #909090 ;
	stroke: #909090 ;
}
.dojoxGaugeRange5 {
	fill: #A0A0A0;
	stroke: #A0A0A0;
}
.dojoxGaugeRange6 {
	fill: #B0B0B0;
	stroke: #B0B0B0;
}
.dojoxGaugeRange7 {
	fill: #C0C0C0;
	stroke: #C0C0C0;
}
.dojoxGaugeRange8 {
	fill: #D0D0D0;
	stroke: #D0D0D0;
}
.dojoxGaugeRange9 {
	fill: #E0E0E0;
	stroke: #E0E0E0;
}
.dojoxGaugeRange10 {
	fill: #F0F0F0;
	stroke: #F0F0F0;
}
.testing {
	fill: blue;
	stroke: blue;
}
