
.nihilo .dijitMenu,
.nihilo .dijitMenuBar {
	border: 1px solid #d3d3d3;
	margin: 0px;
	padding: 0px;
	background-color: #fff;
}
.nihilo .dijitBorderContainer .dijitMenuBar {
	border: 1px #ccc solid;
}
.nihilo .dijitMenuItem {
	font-family: sans-serif;
	margin: 0px;
	color: #243C5F;
}
.nihilo .dijitMenuBar .dijitMenuItem {
	padding: 4px 5px;
}
.nihilo .dijitMenuPreviousButton, .nihilo .dijitMenuNextButton {
	font-style: italic;
}
.nihilo .dijitMenuItem TD {
	padding:1px;
}
.nihilo .dijitMenuPassive .dijitMenuItemHover,
.nihilo .dijitMenuItemSelected {
	background-color: #ffe284; 
	color: #243C5F;
}
.nihilo .dijitMenuItemIcon {
	width: 15px;
	height: 15px;
}
.nihilo .dijitMenuExpand {
	width:15px;
	height:15px;
	background-image: url('images/spriteRoundedIconsSmall.png');
	background-position: -30px top;
}
.dj_ie6 .nihilo .dijitMenuExpand {
	background-image:url('images/spriteRoundedIconsSmall.gif');
}
.nihilo .dijitMenuSeparator {
	height: 1px;
}
.nihilo .dijitMenuSeparatorTop {
	border-bottom: 1px solid #fff; 
}
.nihilo .dijitMenuSeparatorBottom {
	border-top: 1px solid #d3d3d3;
}
.nihilo .dijitCheckedMenuItemIconChar {
	display: none;
}
.nihilo .dijitCheckedMenuItemIcon {
	background-image: url('images/spriteCheckbox.gif');
	background-position: -80px;
}
.nihilo .dijitCheckedMenuItemChecked .dijitCheckedMenuItemIcon {
	background-position: -64px;
}
