({"set":"設定","text":"說明：","insertImageTitle":"影像檔內容","url":"URL：","createLinkTitle":"鏈結內容","newWindow":"New Window","topWindow":"Topmost Window","target":"Target:","parentWindow":"Parent Window","currentWindow":"Current Window"})