({"buttonSet":"설정","insertTableTitle":"테이블 삽입","insertTableRowAfterLabel":"뒤에 행 추가","center":"가운데","deleteTableColumnLabel":"열 삭제","right":"오른쪽","insertTableColumnBeforeLabel":"앞에 열 추가","tableWidth":"테이블 너비:","buttonInsert":"삽입","default":"기본값","align":"맞추기:","insertTableRowBeforeLabel":"앞에 행 추가","cellSpacing":"셀 간격:","pixels":"픽셀","selectTableLabel":"테이블 선택","rows":"행:","modifyTableTitle":"테이블 수정","cellPadding":"셀 채우기:","deleteTableRowLabel":"행 삭제","backgroundColor":"배경색:","insertTableColumnAfterLabel":"뒤에 열 추가","left":"왼쪽","borderThickness":"글꼴 굵기","columns":"열:","percent":"퍼센트","borderColor":"테두리 색:"})