.dojoxSketchIcon{
	background-repeat:no-repeat;
	height:16px;
	min-width:16px;
	text-align:center;
	width:16px;
}
.dojoxSketchIcon { background-image:url(images/icons.gif); }
.ShowCallouts{ background-position:0px 0px; }
.PreviousCallout{ background-position:0px -16px; }
.NextCallout{ background-position:0px -32px; }
.dojoxSketchIconLead{ background-position:0px -48px; }
.dojoxSketchIconUnderline{ background-position:0px -64px; }
.dojoxSketchIconSingleArrow{ background-position:0px -80px; }
.dojoxSketchIconBrace{ background-position:0px -96px; }
.dojoxSketchIconDoubleArrow{ background-position:0px -112px; }
.dojoxSketchIconPreexisting{ background-position:0px -128px; }
