({"buttonSet":"Aseta","insertTableTitle":"Lisää taulukko","insertTableRowAfterLabel":"Lisää rivi jälkeen","center":"keskitetty","deleteTableColumnLabel":"Poista sarake","right":"oikea","insertTableColumnBeforeLabel":"Lisää sarake ennen","tableWidth":"Taulukon leveys:","buttonInsert":"Lisää","default":"oletus","align":"Tasaus:","insertTableRowBeforeLabel":"Lisää rivi ennen","cellSpacing":"Solujen väli:","pixels":"kuvapistettä","selectTableLabel":"Valitse taulukko","rows":"Rivit:","modifyTableTitle":"Muokkaa taulukkoa","cellPadding":"Solun täyttö:","deleteTableRowLabel":"Poista rivi","backgroundColor":"Taustaväri:","insertTableColumnAfterLabel":"Lisää sarake jälkeen","left":"vasen","borderThickness":"Kehyksen paksuus","columns":"Sarakkeet:","percent":"prosenttia","borderColor":"Kehyksen väri:"})