({"dateFormatItem-yM":"yyyy-M","field-dayperiod":"Dayperiod","dateFormatItem-yQ":"yyyy Q","field-minute":"Minuta","eraNames":["p.n.e.","n.e."],"dateFormatItem-MMMEd":"d MMM E","field-weekday":"Dzień tygodnia","dateFormatItem-yQQQ":"y QQQ","dateFormatItem-MMdd":"MM-dd","days-standAlone-wide":["niedziela","poniedziałek","wtorek","środa","czwartek","piątek","sobota"],"dateFormatItem-MMM":"LLL","months-standAlone-narrow":["s","l","m","k","m","c","l","s","w","p","l","g"],"field-era":"Era","field-hour":"Godzina","dateFormatItem-hhmm":"hh:mm a","quarters-standAlone-abbr":["1 kw.","2 kw.","3 kw.","4 kw."],"dateFormatItem-y":"y","timeFormat-full":"HH:mm:ss zzzz","months-standAlone-abbr":["sty","lut","mar","kwi","maj","cze","lip","sie","wrz","paź","lis","gru"],"days-standAlone-narrow":["N","P","W","Ś","C","P","S"],"eraAbbr":["p.n.e.","n.e."],"dateFormatItem-yyyyMM":"yyyy-MM","dateFormatItem-yyyyMMMM":"LLLL y","dateFormat-long":"d MMMM y","timeFormat-medium":"HH:mm:ss","field-zone":"Strefa","dateFormatItem-Hm":"H:mm","dateFormatItem-yyMM":"MM/yy","dateFormat-medium":"dd-MM-yyyy","dateFormatItem-yyMMM":"MMM yy","quarters-standAlone-wide":["I kwartał","II kwartał","III kwartał","IV kwartał"],"dateFormatItem-yMMMM":"LLLL y","dateFormatItem-ms":"mm:ss","field-year":"Rok","quarters-standAlone-narrow":["1","2","3","4"],"dateFormatItem-HHmmss":"HH:mm:ss","months-standAlone-wide":["styczeń","luty","marzec","kwiecień","maj","czerwiec","lipiec","sierpień","wrzesień","październik","listopad","grudzień"],"field-week":"Tydzień","dateFormatItem-MMMMEd":"d MMMM E","dateFormatItem-MMMd":"MMM d","dateFormatItem-HHmm":"HH:mm","dateFormatItem-yyQ":"Q yy","timeFormat-long":"HH:mm:ss z","months-format-abbr":["sty","lut","mar","kwi","maj","cze","lip","sie","wrz","paź","lis","gru"],"timeFormat-short":"HH:mm","field-month":"Miesiąc","quarters-format-abbr":["K1","K2","K3","K4"],"dateFormatItem-MMMMd":"d MMMM","days-format-abbr":["niedz.","pon.","wt.","śr.","czw.","pt.","sob."],"pm":"PM","dateFormatItem-M":"L","dateFormatItem-mmss":"mm:ss","days-format-narrow":["N","P","W","Ś","C","P","S"],"field-second":"Sekunda","field-day":"Dzień","dateFormatItem-MEd":"E, M-d","months-format-narrow":["s","l","m","k","m","c","l","s","w","p","l","g"],"dateFormatItem-hhmmss":"hh:mm:ss a","am":"AM","days-standAlone-abbr":["niedz.","pon.","wt.","śr.","czw.","pt.","sob."],"dateFormat-short":"dd-MM-yy","dateFormatItem-yMMMEd":"EEE, d MMM y","dateFormat-full":"EEEE, d MMMM y","dateFormatItem-Md":"d.M","dateFormatItem-yMEd":"EEE, d.M.yyyy","months-format-wide":["stycznia","lutego","marca","kwietnia","maja","czerwca","lipca","sierpnia","września","października","listopada","grudnia"],"dateFormatItem-d":"d","quarters-format-wide":["I kwartał","II kwartał","III kwartał","IV kwartał"],"days-format-wide":["niedziela","poniedziałek","wtorek","środa","czwartek","piątek","sobota"],"eraNarrow":["p.n.e.","n.e."],"dateTimeFormats-appendItem-Day-Of-Week":"{0} {1}","dateTimeFormat-medium":"{1} {0}","dateFormatItem-EEEd":"d EEE","dateTimeFormats-appendItem-Second":"{0} ({2}: {1})","dateFormatItem-yMMM":"y MMM","dateTimeFormats-appendItem-Era":"{0} {1}","dateTimeFormats-appendItem-Week":"{0} ({2}: {1})","quarters-format-narrow":["1","2","3","4"],"dateTimeFormat-long":"{1} {0}","dateTimeFormat-full":"{1} {0}","dateTimeFormats-appendItem-Day":"{0} ({2}: {1})","dateFormatItem-hm":"h:mm a","dateTimeFormats-appendItem-Year":"{0} {1}","dateTimeFormats-appendItem-Hour":"{0} ({2}: {1})","dateTimeFormats-appendItem-Quarter":"{0} ({2}: {1})","dateTimeFormats-appendItem-Month":"{0} ({2}: {1})","dateTimeFormats-appendItem-Minute":"{0} ({2}: {1})","dateTimeFormats-appendItem-Timezone":"{0} {1}","dateTimeFormat-short":"{1} {0}","dateFormatItem-Hms":"H:mm:ss","dateFormatItem-hms":"h:mm:ss a"})