
.nihilo .dijitDialog {
	background: #eee;
	border: 1px solid #d3d3d3;
	-webkit-box-shadow: 0px 5px 10px #adadad;
	padding: 0px;
}
.nihilo .dijitDialog .dijitDialogTitle {
	
	font-size: 0.9em;
	color: #3243C5F;
	font-weight: bold;
	padding: 0px 4px;
}
.nihilo .dijitDialog .dijitDialogPaneContent {
	background: #ffffff;
	border:none;
	border-top: 1px solid #d3d3d3; 
	padding:10px;
}
.nihilo .dijitDialogTitleBar {
	
	background: #fafafa url("images/titleBar.png") repeat-x top left;
	padding: 5px 6px 3px 6px;
	cursor: move;
	outline:0; 
}
.nihilo .dijitDialogCloseIcon {
	
	background-image: url("images/spriteRoundedIconsSmall.png");
	background-repeat: no-repeat;
	background-position: -60px 0px;
	position: absolute;
	vertical-align: middle;
	right: 6px;
	top: 4px;
	height: 15px;
	width: 15px;
	cursor: pointer;
}
.dj_ie6 .nihilo .dijitDialogCloseIcon {
	background-image: url("images/spriteRoundedIconsSmall.gif");
}
.nihilo .dijitDialogCloseIcon-hover {
	background-position: -60px -15px;
}
.nihilo .dijitTooltip,
.nihilo .dijitTooltipDialog {
	
	background: transparent;	
}
.dijitTooltipBelow {
	
	padding-top: 10px;
}
.dijitTooltipAbove {
	
	padding-bottom: 10px;
}
.nihilo .dijitTooltipContainer {
	
	background-color: #fff;
	border:1px solid #d3d3d3;
	padding:0.45em;
}
.nihilo .dijitTooltipConnector {
	
	border:0px;
	z-index: 2;
}
.nihilo .dijitTooltipABRight .dijitTooltipConnector {
	
	left: auto !important;
	right: 6px;
}
.nihilo .dijitTooltipBelow .dijitTooltipConnector {
	
	top: 0px;
	left: 6px;
	background:url("images/tooltipConnectorUp.png") no-repeat top left;
	width:17px;
	height:11px;
}
.dj_ie .nihilo .dijitTooltipBelow .dijitTooltipConnector {
	background-image: url("images/tooltipConnectorUp.gif");
}
.nihilo .dijitTooltipAbove .dijitTooltipConnector {
	
	bottom: 0px;
	left: 6px;
	background:url("images/tooltipConnectorDown.png") no-repeat top left;
	width:17px;
	height:11px;
}
.dj_ie .nihilo .dijitTooltipAbove .dijitTooltipConnector {
	background-image: url("images/tooltipConnectorDown.gif");
}
.dj_ie6 .nihilo .dijitTooltipAbove .dijitTooltipConnector {
	bottom: -5px;
}
.nihilo .dijitTooltipLeft {
	padding-right: 10px;
}
.dj_ie6 .nihilo .dijitTooltipLeft {
	padding-left: 11px;
}
.nihilo .dijitTooltipLeft .dijitTooltipConnector {
	
	right: 0px;
	bottom: 3px;
	background:url("images/tooltipConnectorRight.png") no-repeat top left;
	width:11px;
	height:17px;
}
.dj_ie .nihilo .dijitTooltipLeft .dijitTooltipConnector {
	background-image: url("images/tooltipConnectorRight.gif");
}
.nihilo .dijitTooltipRight {
	padding-left: 10px;
}
.nihilo .dijitTooltipRight .dijitTooltipConnector {
	
	left: 0px;
	bottom: 3px;
	background:url("images/tooltipConnectorLeft.png") no-repeat top left;
	width:11px;
	height:17px;
}
.dj_ie .nihilo .dijitTooltipRight .dijitTooltipConnector {
	background-image: url("images/tooltipConnectorLeft.gif");
}
