<tr class="feedViewerEntry" dojoAttachPoint="entryNode" dojoAttachEvent="onclick:onClick">
    <td class="feedViewerEntryUpdated" dojoAttachPoint="timeNode">
    </td>
    <td>
        <table border="0" width="100%" dojoAttachPoint="titleRow">
            <tr padding="0" border="0">
                <td class="feedViewerEntryTitle" dojoAttachPoint="titleNode">
                </td>
                <td class="feedViewerEntryDelete" align="right">
                    <span dojoAttachPoint="deleteButton" dojoAttachEvent="onclick:deleteEntry" class="feedViewerDeleteButton" style="display:none;">[delete]</span>
                </td>
            <tr>
        </table>
    </td>
</tr>