.nihilo .dijitComboBox .dijitArrowButton .dijitArrowButtonInner {
	background:url("../images/spriteArrows.png") no-repeat left center;
	width: 11px;
}
.dj_ie6 .nihilo .dijitComboBox .dijitArrowButton .dijitArrowButtonInner {
	background:url("../images/spriteArrows.gif") no-repeat left center;
}
.nihilo .dijitComboBoxHover .dijitArrowButtonInner {
	
}
