.dojoxEllipsis,
.dojoxEllipsisShown {
	white-space: nowrap;
	width: 100%;
	overflow: hidden;
	text-overflow: ellipsis;
	-o-text-overflow: ellipsis;
	-webkit-text-overflow: ellipsis;
}
.dojoxEllipsis window {
    width:100%;
    -moz-user-focus:normal;
    -moz-user-select:text;
}
.dojoxEllipsis description{
    -moz-user-focus:normal;
    -moz-user-select:text;
}
.dojoxEllipsisIFrame{
	white-space: normal;
	border: none;
	width: 100%;
	display: block;
	height: 1px;
	margin-top: -1px;
	clear: both;
}
.dojoxEllipsisContainer{
	width: 100%;
}
.dojoxEllipsisShown:after{
	content: "\2026"
}
