
.nihilo .dijitBorderContainer {
	background-color: #fcfcfc;
	padding: 5px;
}
.nihilo .dijitSplitContainer-child,
.nihilo .dijitBorderContainer-child {
	
    border: 1px #ccc solid;
}
.nihilo .dijitBorderContainer-dijitTabContainerTop,
.nihilo .dijitBorderContainer-dijitTabContainerBottom,
.nihilo .dijitBorderContainer-dijitTabContainerLeft,
.nihilo .dijitBorderContainer-dijitTabContainerRight {
	
	 border: none;
}
.nihilo .dijitBorderContainer-dijitBorderContainer {
	
	border: none;
	padding: 0px;
}
.nihilo .dijitSplitterH,
.nihilo .dijitGutterH {
	background:#FCFCFC;
	border:0;
	border-left:0px solid #d3d3d3;
	border-right:0px solid #d3d3d3;
	height:5px;
}
.nihilo .dijitSplitterH .dijitSplitterThumb {
	background:#8BA0BD none;
	height:1px;
	top:2px;
	width:19px;
}
.nihilo .dijitSplitterV,
.nihilo .dijitGutterV {
	background:#FCFCFC;
	border:0;
	border-top:0px solid #d3d3d3;
	border-bottom:0px solid #d3d3d3;
	width:5px;
}
.nihilo .dijitSplitterV .dijitSplitterThumb {
	background:#8BA0BD none;
	height:19px;
	left:2px;
	width:1px;
}
.nihilo .dijitSplitterActive {
	font-size: 1px;
	background-image: none;
	background-color: #aaa;
	-moz-opacity: 0.6;
	opacity: 0.6;
	filter: Alpha(Opacity=60);
	margin: 0;
}
