({"dateFormatItem-yM":"M-yyyy","field-dayperiod":"dagtid","dateFormatItem-yQ":"Q yyyy","field-minute":"minut","eraNames":["f.Kr.","e.Kr."],"dateFormatItem-MMMEd":"E d MMM","field-weekday":"ugedag","dateFormatItem-hms":"h.mm.ss a","dateFormatItem-yQQQ":"QQQ y","dateFormatItem-MMdd":"dd/MM","days-standAlone-wide":["søndag","mandag","tirsdag","onsdag","torsdag","fredag","lørdag"],"dateFormatItem-MMM":"MMM","months-standAlone-narrow":["J","F","M","A","M","J","J","A","S","O","N","D"],"field-era":"æra","field-hour":"time","quarters-standAlone-abbr":["K1","K2","K3","K4"],"dateFormatItem-y":"y","timeFormat-full":"HH.mm.ss zzzz","dateFormatItem-yyyy":"y","months-standAlone-abbr":["jan","feb","mar","apr","maj","jun","jul","aug","sep","okt","nov","dec"],"dateFormatItem-yMMM":"MMM y","days-standAlone-narrow":["S","M","T","O","T","F","L"],"eraAbbr":["f.Kr.","e.Kr."],"dateFormatItem-yyyyMM":"MM/yyyy","dateFormat-long":"d. MMM y","timeFormat-medium":"HH.mm.ss","field-zone":"zone","dateFormatItem-Hm":"HH.mm","dateFormatItem-yyMM":"MM/yy","dateFormat-medium":"dd/MM/yyyy","dateFormatItem-yyMMM":"MMM yy","quarters-standAlone-wide":["1. kvartal","2. kvartal","3. kvartal","4. kvartal"],"dateFormatItem-yMMMM":"MMMM y","dateFormatItem-ms":"mm.ss","field-year":"år","quarters-standAlone-narrow":["1","2","3","4"],"dateFormatItem-HHmmss":"HH.mm.ss","field-week":"uge","months-standAlone-wide":["januar","februar","marts","april","maj","juni","juli","august","september","oktober","november","december"],"dateFormatItem-MMMMEd":"E, d. MMMM","dateFormatItem-MMMd":"d. MMM","dateFormatItem-yyQ":"Q. 'kvartal' yy","timeFormat-long":"HH:mm:ss z","months-format-abbr":["jan.","feb.","mar.","apr.","maj","jun.","jul.","aug.","sep.","okt.","nov.","dec."],"timeFormat-short":"HH.mm","dateFormatItem-H":"H","field-month":"måned","quarters-format-abbr":["K1","K2","K3","K4"],"dateFormatItem-MMMMd":"d. MMMM","days-format-abbr":["søn","man","tir","ons","tor","fre","lør"],"pm":"e.m.","dateFormatItem-M":"M","days-format-narrow":["S","M","T","O","T","F","L"],"field-second":"sekund","field-day":"dag","dateFormatItem-MEd":"E. d-M","months-format-narrow":["J","F","M","A","M","J","J","A","S","O","N","D"],"dateFormatItem-hm":"h.mm a","am":"f.m.","days-standAlone-abbr":["søn","man","tir","ons","tor","fre","lør"],"dateFormat-short":"dd/MM/yy","dateFormatItem-yMMMEd":"EEE. d. MMM y","dateFormat-full":"EEEE 'den' d. MMMM y","dateFormatItem-Md":"d/M","dateFormatItem-yMEd":"EEE. d-M-yyyy","months-format-wide":["januar","februar","marts","april","maj","juni","juli","august","september","oktober","november","december"],"dateFormatItem-yyyyMMM":"MMM y","dateFormatItem-d":"d.","quarters-format-wide":["1. kvartal","2. kvartal","3. kvartal","4. kvartal"],"days-format-wide":["søndag","mandag","tirsdag","onsdag","torsdag","fredag","lørdag"],"eraNarrow":["f.Kr.","e.Kr."],"dateTimeFormats-appendItem-Day-Of-Week":"{0} {1}","dateTimeFormat-medium":"{1} {0}","dateFormatItem-EEEd":"d EEE","dateTimeFormats-appendItem-Second":"{0} ({2}: {1})","dateTimeFormats-appendItem-Era":"{0} {1}","dateTimeFormats-appendItem-Week":"{0} ({2}: {1})","quarters-format-narrow":["1","2","3","4"],"dateTimeFormat-long":"{1} {0}","dateTimeFormat-full":"{1} {0}","dateTimeFormats-appendItem-Day":"{0} ({2}: {1})","dateTimeFormats-appendItem-Year":"{0} {1}","dateTimeFormats-appendItem-Hour":"{0} ({2}: {1})","dateTimeFormats-appendItem-Quarter":"{0} ({2}: {1})","dateTimeFormats-appendItem-Month":"{0} ({2}: {1})","dateTimeFormats-appendItem-Minute":"{0} ({2}: {1})","dateTimeFormats-appendItem-Timezone":"{0} {1}","dateTimeFormat-short":"{1} {0}","dateFormatItem-Hms":"H:mm:ss"})