
.soria .dijitButtonNode {
	
	
	border: 1px solid #8ba0bd;
	border-bottom:1px solid #657c9c;
	padding: 0.1em 0.2em 0.2em 0.2em;
	background: #bcd5f0 url("../images/buttonEnabled.png") repeat-x top left;
}
.soria .dijitSelect .dijitButtonContents {
	border-right: none;
}
.soria .dijitButtonNode button {
	border: 0px;
	background-color: transparent;
}
.soria .dijitButtonText {
	text-align: center;
	padding: 0 0.3em;
}
.soria .dijitComboBox .dijitButtonNode {
	border-width: 0px 0px 0px 1px;
}
.soria .dijitArrowButton {
	color: #111;
}
.soria .dijitComboButton .dijitDownArrowButton {
	padding-right:4px;
}
.soria .dijitComboBoxReadOnly,
.soria .dijitSpinnerReadOnly,
.soria .dijitSpinnerReadOnly .dijitButtonNode,
.soria .dijitButtonDisabled .dijitButtonNode,
.soria .dijitToggleButtonDisabled .dijitButtonNode,
.soria .dijitDropDownButtonDisabled .dijitButtonNode,
.soria .dijitComboButtonDisabled .dijitButtonNode,
.soria .dijitComboBoxDisabled,
.soria .dijitSpinnerDisabled,
.soria .dijitSpinnerDisabled .dijitButtonNode {
	
	border-color: #b9bbdd #b9bbdd #b9bbdd #b9bbdd;
	background:#c3d3e5 url("../images/buttonDisabled.png") top repeat-x;
	opacity: 0.60;
}
.dj_ie6 .soria .dijitComboButtonDisabled .dijitButtonText {
	
	color: #aaa;
}
.soria .dijitButtonHover .dijitButtonNode,
.soria .dijitButtonNodeHover,
.soria .dijitToggleButtonHover .dijitButtonNode,
.soria .dijitDropDownButtonHover .dijitButtonNode,
.soria .dijitComboButtonHover .dijitButtonContents,
.soria .dijitComboButtonDownArrowHover .dijitDownArrowButton,
.soria .dijitComboBoxHover .dijitDownArrowButton,
.soria .dijitSpinnerUpArrowHover .dijitUpArrowButton,
.soria .dijitSpinnerDownArrowHover .dijitDownArrowButton {
	
	
	color:#243C5F;
	background:#acc5e2 url("../images/buttonHover.png") repeat-x top left;
}
.soria .dijitButtonActive .dijitButtonNode,
.soria .dijitToggleButtonActive .dijitButtonNode,
.soria .dijitDropDownButtonActive .dijitButtonNode,
.soria .dijitComboButtonActive .dijitButtonContents,
.soria .dijitStackController .dijitToggleButtonChecked .dijitButtonNode {
	
	border-color:#657c9c;
	background: #91b4e5 url("../images/buttonActive.png") top left repeat-x;
}
.soria .dijitSpinnerUpArrowActive .dijitUpArrowButton,
.soria .dijitSpinnerDownArrowActive .dijitDownArrowButton,
.soria .dijitComboBoxActive .dijitDownArrowButton {
	
	background: #91b4e5 url("../images/buttonActive.png") top left repeat-x;
}
.soria .dijitArrowButtonInner {
	background-image: url("../images/spriteArrows.png");
	background-repeat: no-repeat;
	background-position: 0px top;
	width: 11px;
}
.soria .dijitLeftArrowButton .dijitArrowButtonInner {
	background-position: -11px top;
}
.soria .dijitUpArrowButton .dijitArrowButtonInner {
	background-position: -22px top;
}
.soria .dijitRightArrowButton .dijitArrowButtonInner {
	background-position: -33px top;
}
.dj_ie6 .soria .dijitArrowButtonInner {
	background-image: url("../images/spriteArrows.gif");
}
