({"buttonSet":"Définir","insertTableTitle":"Insérer un tableau","insertTableRowAfterLabel":"Ajouter une ligne après","center":"centré","deleteTableColumnLabel":"Supprimer la colonne","right":"aligné à droite","insertTableColumnBeforeLabel":"Ajouter une colonne avant","tableWidth":"Largeur de table :","buttonInsert":"Insérer","default":"par défaut","align":"Aligner :","insertTableRowBeforeLabel":"Ajouter une ligne avant","cellSpacing":"Espacement des cellules :","pixels":"pixels","selectTableLabel":"Sélectionner une table","rows":"Lignes :","modifyTableTitle":"Modifier un tableau","cellPadding":"Remplissage des cellules :","deleteTableRowLabel":"Supprimer la ligne","backgroundColor":"Couleur d'arrière-plan :","insertTableColumnAfterLabel":"Ajouter une colonne après","left":"aligné à gauche","borderThickness":"Epaisseur des bordures","columns":"Colonnes :","percent":"pourcentage","borderColor":"Couleur des bordures :"})