.feedEntryViewer {
        color:#000000;
        background: #FFFFFF;
}
.feedEntryViewerMenuTable {
        background: #C0C0C0;      
        border:2px solid;
        border-top-color: lightgrey;
        border-left-color: lightgrey;
        border-right-color: darkgray;
        border-bottom-color: darkgray;
		margin: 0;
}
.feedEntryViewerMenu, .peopleEditorButton {
        cursor: pointer;
        color:#0000FF;
        text-align: left;
        font-size:  small;
}
.feedEntryViewerDisplayCheckbox {
        font-size:  small;
        text-align: left;
}
.feedEntryViewerMenu:hover, .peopleEditorButton:hover {
        text-decoration: underline;
}
.feedEntryViewerContainer, .feedEntryViewerContainer table {
		border-width: 0;
		margin: 0;
}
.feedEntryViewerTitle {
        color:#000000;
        background: #FFFFFF;
        text-align: left;
        
        font-size:  125%;
        font-weight: bold; 
}
.feedEntryViewerAuthor {
        color:#000000;
        background: #FFFFFF;
}
.feedEntryViewerAuthorNames {
        color:#000000;
        background: #FFFFFF;
        text-align: left;
        
        font-size:  110%;
        font-style: italic;
        font-weight: normal;
}
.feedEntryViewerSummary {
        color:#000000;
        background: #FFFFFF;
}
.feedEntryViewerUpdated {
        color:#000000;
        background: #FFFFFF;
}
.feedEntryViewerUpdatedText {
        color:#000000;
        background: #FFFFFF;
        font-size:  110%;
        font-style: italic;
        font-weight: normal;
}
.feedEntryViewerId {
        color:#000000;
        background: #FFFFFF;
}
.feedEntryViewerIdText {
        color:#000000;
        background: #FFFFFF;
        font-style: italic;
        font-size:  110%;
        font-weight: normal;
}
.feedEntryViewerContent {
        color:#000000;
        background: #FFFFFF;
}
.feedEntryViewerContributorNames {
        color:#000000;
        text-align: left;
        
        font-size:  125%;
        font-weight: normal;
}
.feedEntryViewer table {
}
