
.dijitRtl .soria .dijitEditorIcon {
	background-image: url('images/editor_rtl.gif'); 
}
.dijitRtl .soria .dijitDisabled .dijitEditorIcon {
	background-image: url('images/editorDisabled_rtl.gif'); 
}
.dijitRtl .soria .dijitToolbar .dijitToolbarSeparator {
	background-image: url('images/editor_rtl.gif');
}
