
.soria .dijitToggleButton .dijitCheckBox,
.soria .dijitToggleButton .dijitCheckBoxIcon {
	background-image: url('../images/spriteCheckbox.gif');
}
.soria .dijitCheckBox,
.soria .dijitCheckBoxIcon {		
	background-image: url('../images/spriteCheckbox.gif'); 
	background-repeat: no-repeat;
	width: 16px;
	height: 16px;
	margin: 0;
	padding: 0;
}
.soria .dijitCheckBox,
.soria .dijitToggleButton .dijitCheckBoxIcon {
	
	background-position: -16px;
}
.soria .dijitCheckBoxChecked,
.soria .dijitToggleButtonChecked .dijitCheckBoxIcon {
	
	background-position: 0px;
}
.soria .dijitCheckBoxDisabled {
	
	background-position: -48px;
}
.soria .dijitCheckBoxCheckedDisabled {
	
	background-position: -32px;
}
.soria .dijitCheckBoxHover {
	
	background-position: -80px;
}
.soria .dijitCheckBoxCheckedHover {
	
	background-position: -64px;
}
