({"dateFormatItem-yM":"y-M","dateTimeFormats-appendItem-Second":"{0} ({2}: {1})","dateFormatItem-yQ":"y Q","eraNames":["AH"],"dateFormatItem-MMMEd":"E MMM d","dateTimeFormat-full":"{1} {0}","dateFormatItem-hms":"h:mm:ss a","dateFormatItem-yQQQ":"y QQQ","days-standAlone-wide":["1","2","3","4","5","6","7"],"dateFormatItem-MMM":"LLL","months-standAlone-narrow":["1","2","3","4","5","6","7","8","9","10","11","12"],"dateTimeFormats-appendItem-Year":"{0} {1}","dateTimeFormat-short":"{1} {0}","dateTimeFormat-medium":"{1} {0}","quarters-standAlone-abbr":["Q1","Q2","Q3","Q4"],"dateFormatItem-y":"y","timeFormat-full":"HH:mm:ss zzzz","dateTimeFormats-appendItem-Week":"{0} ({2}: {1})","dateTimeFormats-appendItem-Timezone":"{0} {1}","months-standAlone-abbr":["Muharram","Safar","Rabiʻ I","Rabiʻ II","Jumada I","Jumada II","Rajab","Shaʻban","Ramadan","Shawwal","Dhuʻl-Qiʻdah","Dhuʻl-Hijjah"],"dateFormatItem-yMMM":"y MMM","dateTimeFormats-appendItem-Month":"{0} ({2}: {1})","days-standAlone-narrow":["1","2","3","4","5","6","7"],"eraAbbr":["AH"],"dateFormat-long":"y MMMM d","timeFormat-medium":"HH:mm:ss","dateFormatItem-EEEd":"d EEE","dateTimeFormats-appendItem-Minute":"{0} ({2}: {1})","dateFormatItem-Hm":"H:mm","dateFormat-medium":"y MMM d","dateFormatItem-Hms":"H:mm:ss","quarters-standAlone-wide":["Q1","Q2","Q3","Q4"],"dateFormatItem-yMMMM":"y MMMM","dateFormatItem-ms":"mm:ss","quarters-standAlone-narrow":["1","2","3","4"],"dateTimeFormat-long":"{1} {0}","months-standAlone-wide":["Muharram","Safar","Rabiʻ I","Rabiʻ II","Jumada I","Jumada II","Rajab","Shaʻban","Ramadan","Shawwal","Dhuʻl-Qiʻdah","Dhuʻl-Hijjah"],"dateTimeFormats-appendItem-Day":"{0} ({2}: {1})","dateFormatItem-MMMMEd":"E MMMM d","quarters-format-narrow":["1","2","3","4"],"dateFormatItem-MMMd":"MMM d","timeFormat-long":"HH:mm:ss z","months-format-abbr":["Muharram","Safar","Rabiʻ I","Rabiʻ II","Jumada I","Jumada II","Rajab","Shaʻban","Ramadan","Shawwal","Dhuʻl-Qiʻdah","Dhuʻl-Hijjah"],"timeFormat-short":"HH:mm","dateTimeFormats-appendItem-Quarter":"{0} ({2}: {1})","dateFormatItem-MMMMd":"MMMM d","quarters-format-abbr":["Q1","Q2","Q3","Q4"],"days-format-abbr":["1","2","3","4","5","6","7"],"pm":"PM","dateFormatItem-M":"L","days-format-narrow":["1","2","3","4","5","6","7"],"dateTimeFormats-appendItem-Day-Of-Week":"{0} {1}","dateFormatItem-MEd":"E, M-d","months-format-narrow":["1","2","3","4","5","6","7","8","9","10","11","12"],"dateFormatItem-hm":"h:mm a","dateTimeFormats-appendItem-Hour":"{0} ({2}: {1})","am":"AM","days-standAlone-abbr":["1","2","3","4","5","6","7"],"dateFormat-short":"yyyy-MM-dd","dateFormatItem-yMMMEd":"EEE, y MMM d","dateFormat-full":"EEEE, y MMMM dd","dateFormatItem-Md":"M-d","dateFormatItem-yMEd":"EEE, y-M-d","months-format-wide":["Muharram","Safar","Rabiʻ I","Rabiʻ II","Jumada I","Jumada II","Rajab","Shaʻban","Ramadan","Shawwal","Dhuʻl-Qiʻdah","Dhuʻl-Hijjah"],"dateTimeFormats-appendItem-Era":"{0} {1}","dateFormatItem-d":"d","quarters-format-wide":["Q1","Q2","Q3","Q4"],"eraNarrow":["AH"],"days-format-wide":["1","2","3","4","5","6","7"]})