.dojoxPortlet {
	margin-bottom: 5px;
}
.dojoxPortlet .dijitTitlePaneTitle .dojoxPortletIcon {
	width: 15px;
	height: 15px;
	float: right;
	cursor: pointer;
	background-repeat: no-repeat;
}
.tundra .dojoxPortlet-movable .dijitTitlePaneTitle,
.soria .dojoxPortlet-movable .dijitTitlePaneTitle,
.nihilo .dojoxPortlet-movable .dijitTitlePaneTitle {
	cursor: move;
}
.dojoxPortlet .dijitTitlePaneTitle {
	font-weight: bold;
	font-size: 0.9em;
}
.soria .dojoxPortlet .dijitTitlePaneTitle {
	color: #243C5F;
}
.tundra .dojoxPortlet .dijitTitlePaneTitle,
.nihilo .dojoxPortlet .dijitTitlePaneTitle {
	color: #333;
}
.dojoxPortlet-nonmovable .dijitTitlePaneTitle {
	cursor: default;
}
.tundra .dojoxPortlet .dojoxPortletIcon {
	background-image: url("../../../dijit/themes/tundra/images/spriteRoundedIconsSmall.gif");
}
.soria .dojoxPortlet .dojoxPortletIcon {
	background-image: url("../../../dijit/themes/soria/images/spriteRoundedIconsSmall.gif");
}
.nihilo .dojoxPortlet .dojoxPortletIcon {
	background-image: url("../../../dijit/themes/nihilo/images/spriteRoundedIconsSmall.gif");
}
.dojoxPortlet .dojoxCloseNode, 
.dojoxPortlet .dojoxCloseNode {
	background-position: right 0px;
}
.dojoxPortlet .dojoxCloseNodeHover {
	background-position: right -15px;
}
.tundra .dojoxPortlet .dijitOpen .dojoxArrowDown,
.soria .dojoxPortlet .dijitOpen .dojoxArrowDown,
.nihilo .dojoxPortlet .dijitOpen .dojoxArrowDown {
	background-position: -15px top;
}
.tundra .dojoxPortlet .dijitClosed .dojoxArrowDown,
.soria .dojoxPortlet .dijitClosed .dojoxArrowDown,
.nihilo .dojoxPortlet .dijitClosed .dojoxArrowDown {
	background-position: 0 top;
}
.tundra .dojoxPortlet .dojoxPortletSettingsIcon,
.soria .dojoxPortlet .dojoxPortletSettingsIcon,
.nihilo .dojoxPortlet .dojoxPortletSettingsIcon {
	background-image: url(images/icons.png);
	background-position: 0 1px;
}
.tundra .dojoxPortletSettingsContainer,
.soria .dojoxPortletSettingsContainer,
.nihilo .dojoxPortletSettingsContainer {
	border-bottom: 1px solid #BFBFBF;
	padding: 4px;
}
.tundra .dijitDialogPaneContent .dojoxPortletSettingsContainer,
.soria .dijitDialogPaneContent .dojoxPortletSettingsContainer,
.nihilo .dijitDialogPaneContent .dojoxPortletSettingsContainer {
	border-bottom: none;
}
.soria .dojoDndItemOver .dojoxPortletTitle {
  border-top: 1px solid #8D8D8D;
	border-left: 1px solid #8D8D8D;
	border-right: 1px solid #8D8D8D;
}
.soria .dojoDndItemOver .dojoxPortletContentOuter {
  border-bottom: 1px solid #9D9D9D;
	border-left: 1px solid #9D9D9D;
	border-right: 1px solid #9D9D9D;
}
.dojoxPortlet div.dojoxPortletContentOuter {
	background: url(../../../dijit/themes/tundra/images/validationInputBg.gif) repeat-x top left;
}
.dojoxFeedPortletList {
	padding-left: 25px;
	margin: 0px;
}
.dojoxFeedPortletExpandableList {
	padding-left: 0px;
	margin: 0px;
}
.dojoxFeedPortletExpandableList li {
	margin-bottom: 5px;
}
.dojoxFeedPortletList li {
	padding-top: 4px;
}
.dojoxFeedPortletPreview {
	max-height: 300px;
	max-width: 400px;
	overflow: hidden;
}
.dojoxFeedPortletPreview * {
	max-height: 295px;
	max-width: 395px;
}
.dojoxPortletFeedSettings {
	padding: 5px;
	border-bottom: 1px solid #9D9D9D;
}
.dojoxFeedPortletExpandableList {
	list-style: none;
}
.dojoxPortletToggleIcon {
	margin-right: 6px;
	cursor: pointer;
}
.dojoxPortletToggleIcon img {
	width: 15px;
	height: 14px;
}
.dojoxPortletItemCollapsed .dojoxPortletToggleIcon {
	background: url(../../../dijit/themes/tundra/images/plusButton.gif) no-repeat 0 0;
}
.dojoxPortletItemOpen .dojoxPortletToggleIcon {
	background: url(../../../dijit/themes/tundra/images/minusButton.gif) no-repeat 0 0;
}
.dojoxPortletItemSummary {
	margin-left: 20px;
}
.dojoxPortletItemCollapsed .dojoxPortletItemSummary {
  display: none;
}
.dojoxPortletItemOpen .dojoxPortletItemSummary {
  display: block;
}
