.tundra .dijitToggleButton .dijitCheckBoxIcon {
	background-image: url('../images/checkmarkNoBorder.png');
}
.dj_ie6 .tundra .dijitToggleButton .dijitCheckBoxIcon {
	background-image: url('../images/checkmarkNoBorder.gif');
}
.tundra .dijitCheckBox,
.tundra .dijitCheckBoxIcon			{
	background-image: url('../images/checkmark.png'); 
	background-repeat: no-repeat;
	width: 16px;
	height: 16px;
	margin: 0 2px 0 0;
	padding: 0;
}
.dj_ie6 .tundra .dijitCheckBox,
.dj_ie6 .tundra .dijitCheckBoxIcon			{
	background-image: url('../images/checkmark.gif'); 
}
.tundra .dijitCheckBox,
.tundra .dijitToggleButton .dijitCheckBoxIcon {
	
	background-position: -16px;
}
.tundra .dijitCheckBoxChecked,
.tundra .dijitToggleButtonChecked .dijitCheckBoxIcon {
	
	background-position: 0px;
}
.tundra .dijitCheckBoxDisabled {
	
	background-position: -48px;
}
.tundra .dijitCheckBoxCheckedDisabled {
	
	background-position: -32px;
}
.tundra .dijitCheckBoxHover {
	
	background-position: -80px;
}
.tundra .dijitCheckBoxCheckedHover {
	
	background-position: -64px;
}
