
.tundra .dijitTabPaneWrapper {
	background:#fff;
	border:1px solid #ccc;
	margin: 0;
	padding: 0;
}
.tundra .dijitTab {
	line-height:normal;
	margin-right:4px;	
	padding:0px;
	border:1px solid #ccc;
	background:#e2e2e2 url("../images/tabEnabled.png") repeat-x;
}
.tundra .dijitTabInnerDiv {
	padding:2px 8px 2px 9px;
}
.tundra .dijitTabSpacer {
	display: none;
}
.tundra .dijitTabContainer .tabStripRBtn {
	margin-right: 20px;
}
.tundra .dijitTabContainer .tabStripLBtn {
	margin-left: 20px;
}
.tundra .nowrapTabStrip .dijitTab {
	top: 2px;
}
.tundra .dijitTabContainerBottom .nowrapTabStrip .dijitTab {
	top: 0px;
	bottom: 2px;
}
.tundra .dijitTabContainer .tabStripMenuButton-Hover {
	cursor: pointer;
}
.tundra .dijitTabChecked {
	
	background-color:#fff;
	border-color: #ccc;
	background-image:none;
}
.tundra .dijitTabHover {
	color: #243C5F;
	border-top-color:#92a0b3;
	border-left-color:#92a0b3;
	border-right-color:#92a0b3;
	border-bottom-color:#92a0b3;
	background:#e2e2e2 url("../images/tabHover.gif") repeat-x;
}
.tundra .dijitTabContainerTop .dijitTabHover {
	border-bottom-color:#ccc;
}
.tundra .dijitTabContainerBottom .dijitTabHover {
	border-top-color:#ccc;
}
.tundra .dijitTabContainerLeft .dijitTabHover {
	border-right-color:#ccc;
}
.tundra .dijitTabContainerRight .dijitTabHover {
	border-left-color:#ccc;
}
.tundra .dijitTabContainer .dijitTabCheckedHover {
	color: inherit;
	border:1px solid #ccc;
	background:#fff;
}
.tundra .dijitTab .dijitClosable .closeImage {
	background: url("../images/tabClose.png") no-repeat right top;
	width: 12px;
	height: 12px;
}
.tundra .dijitTab .tabLabel {
	
	min-height: 12px;
	display: inline-block;
}
.tundra .dijitTabContainerNested .dijitTabListWrapper {
	height: auto;
}
.tundra .dijitTabContainerNested .dijitTabContainerTop-tabs {
	border-bottom: 1px solid #CCC;
}
.tundra .dijitTabContainerTabListNested .dijitTab {
	background: none;
	border: none;
	top: 0px;		
}
.tundra .dijitTabContainerTabListNested .dijitTab .dijitTabContent {
}
.tundra .dijitTabContainerTabListNested .dijitTabHover .dijitTabContent .tabLabel {
	text-decoration: underline;
}
.tundra .dijitTabContainerTabListNested .dijitTabChecked .dijitTabContent .tabLabel {
	text-decoration: underline;
	font-weight: bold;
	
}
.tundra .dijitTabContainer .dijitTabPaneWrapperNested {
	border: none;	
}
.tundra .dijitTab .closeImage {
	background-image : url("../images/tabClose.png");
}
.dj_ie6 .tundra .dijitTab .closeImage {
	background-image : url("../images/tabClose.gif");
}
.tundra .dijitTab .closeButton-hover .closeImage {
	background-image : url("../images/tabCloseHover.png");
}
.dj_ie6 .tundra .dijitTab .closeButton-hover .closeImage {
	background-image : url("../images/tabCloseHover.gif");
}
.tundra .dijitTabContainerTop-tabs {
	margin-bottom: 0px;
	border-color: #cccccc;
	padding-left: 3px;
	background-position: bottom;
}
.tundra .dijitTabContainerTop-tabs .dijitTab {
	top: 0px;
	margin-bottom: -1px;
}
.tundra .dijitTabContainerTop-container {
	border-top: none;
}
.tundra .dijitTabContainerTop-tabs .dijitTabChecked {
	border-bottom-color:white;
}
.tundra .dijitTabContainerTop-tabs,
.tundra .dijitTabContainerBottom-tabs {
	padding-left: 3px;
	padding-right: 3px;
}
.tundra .dijitTabContainerTopStrip {
	border-top: 1px solid #CCC;
	border-right: 1px solid #CCC;
	border-left: 1px solid #CCC;
	padding-top: 2px;
	background: #f2f2f2;
}
.tundra .dijitTabContainerTopNone {
	padding-top: 0px;
}
.tundra .dijitTabContainerBottom-tabs {
	margin-top: 0px;
	border-color: #cccccc;
	background-position: top;
	padding-left: 3px;
}
.tundra .dijitTabContainerBottom-tabs .dijitTab {
	bottom: 0px;
	margin-top: -1px;
}
.tundra .dijitTabContainerBottom-container {
	border-bottom: none;
}
.tundra .dijitTabContainerBottom-tabs .dijitTabChecked {
	border-top-color:white;
}
.tundra .dijitTabContainerBottomStrip {
	padding-bottom: 2px;
	border: 1px solid #ccc;
	background: #f2f2f2;
	border-top: none;
}
.tundra .dijitTabContainerRight-tabs {
	border-color: #ccc;
	height: 100%;
	padding-top: 3px;
}
.tundra .dijitTabContainerRightStrip {
	margin-left: -1px;
}
.tundra .dijitTabContainerRight-container {
	border-right: none;
}
.tundra .dijitTabContainerRight-tabs .dijitTabChecked {
	border-left-color:white;
}
.tundra .dijitTabContainerRightStrip {
	padding-right: 2px;
	border: 1px solid #ccc;
}
.tundra .dijitTabContainerRightStrip {
	background: #f2f2f2;
}
.tundra .dijitTabContainerLeft-tabs {
	border-color: #ccc;
	padding-top: 3px;
	height: 100%;
}
.tundra .dijitTabContainerLeft .dijitTabListWrapper {
}
.tundra .dijitTabContainerLeft-container {
	border-left: none;
}
.tundra .dijitTabContainerLeft-tabs .dijitTabChecked {
	border-right-color:white;
}
.tundra .dijitTabContainerLeftStrip {
	padding-left: 2px;
	border: 1px solid #ccc;
	background: #f2f2f2;
	border-right: none;
}
.tundra .dijitTabContainerLeft-tabs .dijitTab,
.tundra .dijitTabContainerRight-tabs .dijitTab {
	margin-right:0px;
	margin-bottom:4px;	
}
.tundra .dijitTabContainerTop-dijitContentPane .dijitTabContainerTop-tabs {
	border-left: 0px solid #ccc;
	border-top: 0px solid #ccc;
	border-right: 0px solid #ccc;
	padding-top: 0px;
	padding-left: 0px;
}
.tundra .dijitTabContainer .tabStripButton {
	margin-right: 0;
	padding-top: 2px;
	z-index: 12;
}
.tundra .dijitTabContainerBottom .tabStripButton {
	padding-top: 2px;
}
.tundra .tabStrip-disabled .tabStripButton .dijitTabInnerDiv {
	padding-bottom: 3px;
	padding-top: 1px;
}
.tundra .tabStripButton .dijitTabInnerDiv {
	padding: 3px 2px 4px 2px;
}
.dj_ie6 .tundra .tabStripButton .dijitTabInnerDiv,
.dj_ie7 .tundra .tabStripButton .dijitTabInnerDiv,
.dj_opera .tundra .tabStripButton .dijitTabInnerDiv {
	padding-bottom: 5px;
}
.dj_ie6 .tundra .tabStrip-disabled .tabStripButton .dijitTabInnerDiv,
.dj_ie7 .tundra .tabStrip-disabled .tabStripButton .dijitTabInnerDiv,
.dj_opera .tundra .tabStrip-disabled .tabStripButton .dijitTabInnerDiv {
	padding-bottom: 4px;
}
.tundra .dijitTabContainer .tabStripButton {
	
	width: 21px;
}
.tundra .dijitTabContainer .tabStripButton img {
	height: 14px;
	background: url(../images/spriteRoundedIconsSmall.png) no-repeat;
}
.dj_ie6 .tundra .dijitTabContainer .tabStripButton img {
	background-image: url(../images/spriteRoundedIconsSmall.gif);
}
.tundra .dijitTabContainer .tabStripMenuButton img {
	background-position: -15px top;
}
.tundra .dijitTabContainer .tabStripSlideButtonLeft img {
	background-position: 0px top;
}
.tundra .dijitTabContainer .tabStripSlideButtonRight img {
	background-position: -30px top;
}
