.pagerContainer {
	position: relative;
	height: 100%;
	width: 100%;
	overflow: hidden;
	
	border:1px solid #ccc;
	-moz-border-radius:6pt;
	-webkit-border-radius:7pt;
}
.horizontalPagerPager {
	position: absolute;
	height: 12px;
	width: 100%;
	padding-top: 4px;
	padding-bottom: 4px;
}
.horizontalPagerStatus {
	position: absolute;
	height: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
	width: 100%;
}
.horizontalPagerView {
	position: absolute;
	height: 100%;
	width: 100%;
	overflow: hidden;
}
.horizontalPagerIcon {
	cursor: pointer;	
}
.verticalPagerPager {
	position: absolute;
	width: 12px;
	height: 100%;
	padding-left: 4px;
	padding-right: 4px;
}
.verticalPagerStatus {
	position: absolute;
	width: 10px;
	padding-left: 5px;
	padding-right: 5px;
	height: 100%;
}
.verticalPagerView {
	position: absolute;
	height: 100%;
	width: 100%;
	overflow: hidden;
}
.verticalPagerIcon {
	cursor: pointer;	
}
.pagerIconContainer {
	position: absolute;	
}
.pagerIconContainer img {
	cursor: pointer;	
}
.pagerItems {
	list-style: none;
	padding: 0;
	margin: 0;	
}
	
.pagerItem {
	overflow: hidden;
	padding: 0;
	margin: 0;
}
