.dojoxEditorBreadcrumbArrow .dijitDownArrowButton {
	width: 10px;
}
.dojoxEditorBreadcrumbArrow .dijitArrowButtonInner {
	background-image: url(../icons/breadcrumbDown.gif);
	background-repeat: no-repeat;
	background-position: center center;
	width: 8px;
	height: 8px;
}
