({"quarters-format-abbr":["רבעון 1","רבעון 2","רבעון 3","רבעון 4"],"dateFormat-medium":"dd/MM/yyyy","dateFormatItem-MMMEd":"E d MMM","dateFormatItem-yMEd":"EEE, d.M.yyyy","eraNarrow":["שנת היג׳רה"],"dateFormatItem-Md":"d/M","months-standAlone-wide":["מוחרם","ספר","רביע אל-אוואל","רביע אל-תני","ג׳ומדה אל-אוואל","ג׳ומדה אל-תני","רג׳אב","שעבאן","ראמדן","שוואל","זו אל-QI'DAH","זו אל-חיג׳ה"],"eraNames":["שנת היג׳רה"],"days-standAlone-narrow":["א","ב","ג","ד","ה","ו","ש"],"dateFormatItem-MMMMd":"d בMMMM","months-standAlone-abbr":["מוחרם","ספר","רביע אל-אוואל","רביע אל-תני","ג׳ומדה אל-אוואל","ג׳ומדה אל-תני","רג׳אב","שעבאן","ראמדן","שוואל","זו אל-QI'DAH","זו אל-חיג׳ה"],"dateFormat-long":"d בMMMM y","dateFormat-short":"dd/MM/yy","months-format-wide":["מוחרם","ספר","רביע אל-אוואל","רביע אל-תני","ג׳ומדה אל-אוואל","ג׳ומדה אל-תני","רג׳אב","שעבאן","ראמדן","שוואל","זו אל-QI'DAH","זו אל-חיג׳ה"],"dateFormatItem-yMMMM":"MMMM y","dateFormatItem-yM":"M.yyyy","months-format-abbr":["מוחרם","ספר","רביע אל-אוואל","רביע אל-תני","ג׳ומדה אל-אוואל","ג׳ומדה אל-תני","רג׳אב","שעבאן","ראמדן","שוואל","זו אל-QI'DAH","זו אל-חיג׳ה"],"days-format-wide":["יום ראשון","יום שני","יום שלישי","יום רביעי","יום חמישי","יום שישי","יום שבת"],"eraAbbr":["שנת היג׳רה"],"dateFormatItem-yQ":"yyyy Q","quarters-format-wide":["רבעון 1","רבעון 2","רבעון 3","רבעון 4"],"dateFormat-full":"EEEE, d בMMMM y","days-format-abbr":["יום א'","יום ב'","יום ג'","יום ד'","יום ה'","יום ו'","שבת"],"dateTimeFormats-appendItem-Second":"{0} ({2}: {1})","dateTimeFormat-full":"{1} {0}","dateFormatItem-hms":"h:mm:ss a","dateFormatItem-yQQQ":"y QQQ","days-standAlone-wide":["1","2","3","4","5","6","7"],"dateFormatItem-MMM":"LLL","months-standAlone-narrow":["1","2","3","4","5","6","7","8","9","10","11","12"],"dateTimeFormats-appendItem-Year":"{0} {1}","dateTimeFormat-short":"{1} {0}","dateTimeFormat-medium":"{1} {0}","quarters-standAlone-abbr":["Q1","Q2","Q3","Q4"],"dateFormatItem-y":"y","timeFormat-full":"HH:mm:ss zzzz","dateTimeFormats-appendItem-Week":"{0} ({2}: {1})","dateTimeFormats-appendItem-Timezone":"{0} {1}","dateFormatItem-yMMM":"y MMM","dateTimeFormats-appendItem-Month":"{0} ({2}: {1})","timeFormat-medium":"HH:mm:ss","dateFormatItem-EEEd":"d EEE","dateTimeFormats-appendItem-Minute":"{0} ({2}: {1})","dateFormatItem-Hm":"H:mm","dateFormatItem-Hms":"H:mm:ss","quarters-standAlone-wide":["Q1","Q2","Q3","Q4"],"dateFormatItem-ms":"mm:ss","quarters-standAlone-narrow":["1","2","3","4"],"dateTimeFormat-long":"{1} {0}","dateTimeFormats-appendItem-Day":"{0} ({2}: {1})","dateFormatItem-MMMMEd":"E MMMM d","quarters-format-narrow":["1","2","3","4"],"dateFormatItem-MMMd":"MMM d","timeFormat-long":"HH:mm:ss z","timeFormat-short":"HH:mm","dateTimeFormats-appendItem-Quarter":"{0} ({2}: {1})","pm":"PM","dateFormatItem-M":"L","days-format-narrow":["1","2","3","4","5","6","7"],"dateTimeFormats-appendItem-Day-Of-Week":"{0} {1}","dateFormatItem-MEd":"E, M-d","months-format-narrow":["1","2","3","4","5","6","7","8","9","10","11","12"],"dateFormatItem-hm":"h:mm a","dateTimeFormats-appendItem-Hour":"{0} ({2}: {1})","am":"AM","days-standAlone-abbr":["1","2","3","4","5","6","7"],"dateFormatItem-yMMMEd":"EEE, y MMM d","dateTimeFormats-appendItem-Era":"{0} {1}","dateFormatItem-d":"d"})