.dijitAdditionalEditorIconPageBreak {
	background-image: url(../icons/pageBreak.gif);
	background-repeat: no-repeat;
	background-position: center center;
	width: 18px;
	height: 18px;
}
.dijitDisabled .dijitAdditionalEditorIconPageBreak {
	background-image: url(../icons/pageBreakDisabled.gif);
	background-repeat: no-repeat;
	background-position: center center;
	width: 18px;
	height: 18px;
}
